@@ -1,8 +1,15 @@
 #
-wm withdraw .
+set NoGUI 0
+if {[catch {wm withdraw .}]} {
+    set NoGUI 1
+    proc tk_dialog {a1 a2 msg args} {
+	puts stderr $msg
+    }
+    proc update {} {}
+}
 #
 if {![file exists installer] || ![file isdirectory installer]} {
-    tk_dialog .err {Zircon Installer} {You must have run the installer\
+    tk_dialog .err {Zircon Installer} {You must run the installer\
       with the zircon distribution directory as your current \
       directory!} error 0 Quit
     update
@@ -13,18 +20,22 @@ switch -glob [info tclversion] {
 {[123456]\.*} -
 {7\.[1234]} {
 	tk_dialog .err {Zircon Installer} {You must have tcl7.5 or newer\
-          in order to run Zircon} info 0 Quit
+          in order to run Zircon. I recommend tcl 8.0 or better} info 0 Quit
 	update
 	exit 0
     }
 7\.5 { 
 	tk_dialog .err {Zircon Installer} {I see you are running \
-          tcl7.5/tk4.1. Zircon will work perfectly well with this \
-	  version, but you really ought to upgrade to the latest \
-          release!} info 0 OK
+          tcl7.5/tk4.1. Time is running out! Future versions of zircon will not support tcl7.*.} info 0 OK
 	update
     }
-default {}
+7\.6 { 
+	tk_dialog .err {Zircon Installer} {I see you are running \
+          tcl7.6/tk4.2. Time is running out and you really ought to upgrade to the latest \
+          release! Future versions of zircon will not support tcl7.*.} info 0 OK
+	update
+    }
+    default {}
 }
 #
 set auto_path [linsert $auto_path 0 [file join [pwd] installer]]
@@ -32,7 +43,7 @@ set auto_path [linsert $auto_path 0 [file join [pwd] installer]]
 source [file join installer manifest.tcl]
 #
 foreach x [array names Manifest] {
-    if ![file exists $x] {
+    if {![file exists $x]} {
 	tk_dialog .err {Zircon Installer} "Missing file - $x" error 0 Quit
 	update
 	exit 0	
