@@ -6,6 +6,7 @@ array set Manifest [list  \
     README				{} \
     README.ONS				{} \
     README.load				{} \
+    README.look				{} \
     README.prefs			{} \
     CHANGES				{} \
     COPYRIGHT				{} \
@@ -49,11 +50,13 @@ array set Manifest [list  \
     [file join lib Control.tcl]		{copy} \
     [file join lib DALnet.tcl]		{copy} \
     [file join lib Entry.tcl]		{copy} \
+    [file join lib Friend.tcl]		{copy} \
     [file join lib Friends.tcl]		{copy} \
     [file join lib IRC.tcl]		{copy} \
     [file join lib Ignore.tcl]		{copy} \
     [file join lib Info.tcl]		{copy} \
     [file join lib Interface.tcl]	{copy} \
+    [file join lib List.tcl]		{copy} \
     [file join lib Log.tcl]		{copy} \
     [file join lib Message.tcl]		{copy} \
     [file join lib Monitor.tcl]		{copy} \
@@ -70,6 +73,7 @@ array set Manifest [list  \
     [file join lib bindings.tcl]	{copy} \
     [file join lib confChan.tcl]	{copy} \
     [file join lib confInfo.tcl]	{copy} \
+    [file join lib confTab.tcl]		{copy} \
     [file join lib config.tcl]		{copy} \
     [file join lib ctcp.tcl]		{copy} \
     [file join lib dialog.tcl]		{copy} \
@@ -99,6 +103,7 @@ array set Manifest [list  \
     [file join lib Mac.tcl]		{copy} \
     [file join lib tcl76.tcl]		{copy} \
     [file join lib tcl80.tcl]		{copy} \
+    [file join lib tcl81.tcl]		{copy} \
     [file join lib Unix.tcl]		{copy} \
     [file join lib Windows.tcl]		{copy} \
     [file join lib debug.tcl]		{copy} \
@@ -109,12 +114,14 @@ array set Manifest [list  \
     [file join plugins Dcc auto.tcl]	{copy}  \
     [file join plugins Dcc chat.tcl]	{copy} \
     [file join plugins Dcc dcc.tcl]	{copy} \
+    [file join plugins Dcc dccget.tcl]	{copy} \
+    [file join plugins Dcc dccsend.tcl]	{copy} \
     [file join plugins Dcc send.tcl]	{copy} \
-    [file join plugins Dcc dccget.c]	{prog} \
-    [file join plugins Dcc dccsend.c]	{prog} \
+    [file join plugins Dcc dccget.c]	{prog7} \
+    [file join plugins Dcc dccsend.c]	{prog7} \
     [file join plugins Sed decrypt.tcl]	{copy} \
-    [file join plugins Sed sed.c]	{libr} \
-    [file join plugins Sed crypt.c]	{prog} \
+    [file join plugins Sed sed.c]	{sed} \
+    [file join plugins Sed crypt.c]	{prog7} \
     [file join help Zircon Windows Info]	{copy} \
     [file join help Zircon Windows Control]	{copy} \
     [file join help Zircon Windows Channel]	{copy} \
@@ -138,6 +145,7 @@ array set Manifest [list  \
     [file join lang espanol.tcl]	{copy} \
     [file join lang italiano.tcl]	{copy} \
     [file join lang suomi.tcl]		{copy} \
+    [file join lang catala.tcl]		{copy} \
     [file join look standard.tcl]	{copy} \
     scripts				{dmake} \
     [file join IRCinfo tao.of.irc]	{} \
@@ -159,21 +167,30 @@ array set Manifest [list  \
     [file join gifs off.gif]		{copy} \
     [file join gifs on.gif]		{copy} \
     [file join gifs button.gif]		{copy} \
+    [file join gifs noii.gif]		{copy} \
+    [file join gifs ii.gif]		{copy} \
+    [file join gifs lock.gif]		{copy} \
+    [file join gifs unlock.gif]		{copy} \
+    [file join gifs zlogo.gif]		{copy} \
     sounds				{dmake} \
     [file join installer install.tcl]	{} \
     [file join installer unix.tcl]	{} \
-    [file join installer file7.5.tcl]	{} \
-    [file join installer file7.6.tcl]	{} \
-    [file join installer file8.0.tcl]	{} \
+    [file join installer file75.tcl]	{} \
+    [file join installer file76.tcl]	{} \
+    [file join installer file80.tcl]	{} \
+    [file join installer file81.tcl]	{} \
     [file join installer support.tcl]	{} \
     [file join installer mac.tcl]	{} \
+    [file join installer macfile.tcl]	{} \
     [file join installer manifest.tcl]	{} \
     [file join installer pkgIndex.tcl]	{} \
     [file join installer windows.tcl]	{} \
+    [file join installer winfile.tcl]	{} \
     [file join installer zircon.tcl]	{} \
 ]
 #
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 32
+set Patchlevel 104
+
