@@ -16,49 +16,65 @@ package require $tcl_platform(platform)
 package require zircon
 package require Debug
 #
+proc zUnknown {args} {
+    switch -glob [set cmd [lindex $args 0]] irc* {
+	set net [lindex $args 1]
+	if {[$net startup]} {$net fast}
+	if {![auto_load $cmd]} { ircNUM $net $cmd $args } { return [uplevel $args] }
+    } default {
+	return [uplevel sys_unknown $args]
+    }
+}
+#
+rename unknown sys_unknown
+rename zUnknown unknown
 #
 Initialise
-InitGlobals
 #
 # save some space!!! it will reload if necessary.
 #
 rename Initialise {}
 rename InitGlobals {}
+rename InitLook {}
+rename InitImages {}
 #
 if {[set l [llength [set nets [Net :: list]]]] == 1} {
     $defaultNet show
-    if [$defaultNet nocontrol] {
-	wm withdraw .@ctl
-	wm withdraw .@inf
+    if {[$defaultNet nocontrol]} {
+	wm withdraw [MainControl]
+	wm withdraw [MainInfo]
     } {
-	exposeFrame .@ctl $defaultNet
-	exposeFrame .@inf [$defaultNet info]
-	hideFrame .@ctl $defaultNet
-	hideFrame .@inf [$defaultNet info]
+	exposeFrame [MainControl] $defaultNet
+	exposeFrame [MainInfo] [$defaultNet info]
+	hideFrame [MainControl] $defaultNet
+	hideFrame [MainInfo] [$defaultNet info]
     }
 } {
     addToConf $defaultNet
     if {$l == 2} {
 	set net [lindex $nets 1]
-	if [$net nocontrol] {
-	    wm withdraw .@ctl
-	    wm withdraw .@inf
+	if {[$net nocontrol]} {
+	    wm withdraw [MainControl]
+	    wm withdraw [MainInfo]
 	} {
-	    exposeFrame .@ctl $net
-	    exposeFrame .@inf [$net info]
+	    exposeFrame [MainControl] $net
+	    exposeFrame [MainInfo] [$net info]
 	}
     }
 }
 unset l
 #
-if !$zircon(C) {
+if {!$zircon(C)} {
     foreach x $znetList {
 	switch nil [set hst [$x hostid]] {} default {
 	    set s [$x servers]
 	    set v [lsearch $s $hst]
 	    listdel s $v
 	    while {![$x startIRC $hst]} {
-		switch {} $s break
+		switch {} $s {
+		    [$x control] enableOpen
+		    break
+		}
 		$x configure -hostid [set hst [lindex $s 0]]
 		set s [lrange $s 1 end]
 		update
