@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1997/07/18 08:01:25 $
-# $Revision: 1.18.1.39 $
+# $Date: 1998/03/02 11:57:39 $
+# $Revision: 1.18.1.63 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,15 +12,16 @@
 package provide zircon 1.18
 #
 proc InitClasses {} {
+    dispAd {Initialising classes...}
 #
 class Channel {
     timestamp	0	{bool}
     noshare	0	{bool}
     monitor	0	{bool}
-    menu	0	{bool}
+    menu	0	{bool {On Menu}}
     join	0	{bool}
-    nocase	0	{bool}
-    nosort	0	{bool}
+    nocase	0	{bool {Ignore Case}}
+    nosort	0	{bool {Do not sort}}
     open	0	{bool}
     close	0	{bool}
     draw	1	{bool}
@@ -29,11 +30,12 @@ class Channel {
     actions	0	{bool}
     buttons	1	{bool}
     closeleave	0	{bool}
-    colour	{}	{list {mirc}}
-    crypt	{}	{key}
+    colour	{}	{list {mirc ctcp2}}
+    crypt	{}	{sedkey}
     key		{}	{key}
     logfile	{}	{file}
-    history	50	{int}
+    history	10	{int}
+    scrollback	50	{int}
     closetime	0	{mseconds}
     patterns	{}	{patterns}
     messages	{}	{texts}
@@ -52,11 +54,14 @@ class Channel {
     width	80	{int}
     timeformat  {%m/%d/%Y %H:%M:%S}	{format}
     joinat	{}	{time}
+    mytag	{>}	{prompt}
+    logtag	{>}	{prompt}
 } {
     name	{}
     lname	{}
     limit	{}
     text	{}
+    ufrm	{}
     stampMsg	0
     logdir	{}
     logactual	{}
@@ -68,12 +73,11 @@ class Channel {
     sys		0
     actionmode	0
     keep	0
-    cinfo	{}
     logfd	{}
     window	{}
     wid		{}
+    closemsec	0
     closecount	0
-    hpos	end
     a		0
     i		0
     m		0
@@ -82,6 +86,10 @@ class Channel {
     q		0
     s		0
     t		0
+    ircIImode	0
+    histbuff	{}
+    hpos	-1
+    mwin	{}
 }
 #
 class Message {
@@ -106,6 +114,7 @@ class DChat {
     draw	0	{bool}
     height	10	{int}
     width	80	{int}
+    mytag	=	{prompt}
 } {
     caller	nil
     sock	{}
@@ -123,6 +132,7 @@ class Server {
     srvmsg	0	{bool}
     undernet	0	{bool}
     irc2.9	0	{bool}
+    encoding	{}	{string}
 } {
     name	{}
     sys		0
@@ -178,9 +188,15 @@ class Friend {
     net		{}
     usr		nil
     ison	0
+    limbo	0
 }
 #
-class Net {
+global zircon
+class Net "
+    setcolour	red	{colour}
+    foreground	$zircon(fg)	{colour}
+    myaddr	{}	{host}
+    myport	{}	{portnumber}
     multion	0	{bool}
     beep	BEEP	{text}
     nosplit	0	{bool}
@@ -213,7 +229,8 @@ class Net {
     noRefresh	1	{bool}
     killPath	1	{bool}
     noConfirm	{}	{list {Quit Leave Kill SaveConf}}
-    toInfo	{}	{list {Ctcp Signoff Who Whois Whowas Error Ison Info}}
+    toInfo	{}	{list {Ctcp Signoff Who Whois Whowas Error Ison Info Kill Close}}
+    alwayslog	{}	{list {Ctcp Signoff Who Whois Whowas Error Ison Info Kill Close}}
     noPopup	0	{bool}
     popInfo	0	{bool}
     busy	0	{bool}
@@ -232,12 +249,16 @@ class Net {
     autoclearaway 0	{bool}
     monitorTime	60000	{mseconds}
     testTime	30000	{mseconds}
-    dccTime	600000	{seconds}
+    quitwait	10000	{mseconds}
+    dccTime	600000	{mseconds}
     notifyInterval	30000	{mseconds}
     ping	0	{mseconds}
     antiflood   2000	{mseconds}
     cleargone   0	{bool}
-} {
+    beeplimit	4	{int}
+    dcclimit	10	{int}
+    helpers	{}	{pairlist}
+" {
     restricted	0
     name	{}
     sock	{}
@@ -254,6 +275,7 @@ class Net {
     gircop	0
     info	{}
     control	{}
+    debug	{}
     nickname	{}
     nicks	{}
     ircname	{}
@@ -268,7 +290,7 @@ class Net {
     sUmodes	{}
     sCmodes	{}
     idle	0
-    confChange	0
+    confChange	{}
     nickwait	0
     msgQueue	{}
     msgQLen	0
@@ -277,7 +299,6 @@ class Net {
     sysQueue	{}
     sysQLen	0
     sysQTag	{}
-    listFile	{}
     splits	{}
     pinged	0
     allChannels {}
@@ -295,6 +316,9 @@ class Net {
     atsrv	0
     atcll	0
     msgclear	{}
+    closing	{}
+    showlist	0
+    listid	{}
 }
 #
 class Control {} {
@@ -308,5 +332,43 @@ class Control {} {
     channel	{}
     smrow	0
 }
+#
+class Friends {} {
+    name	{}
+    window	{}
+    noshare	0
+    close	0
+    control	{}
+    wid		{}
+    style	window
+}
+#
+class Monitor { } {
+    name	{}
+    net		{}
+    channel	{}
+    net		{}
+    window	{}
+    wid		{}
+    close	0
+}
+#
+class List { } {
+    name	{}
+    net		{}
+    wid		{}
+    close	0
+    listPattern .*
+    topicPattern	.*
+    showPublic	1
+    showLocal	1
+    showPrivate	0
+    topicOnly	0
+    minMembers	3
+    maxMembers	0
+    sorted	0
+    nocase	0
+    listfile	{}
+}
 
 }
