@@ -1,29 +1,24 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1997/07/08 11:27:55 $
-# $Revision: 1.18.1.70 $
+# $Date: 1998/02/26 09:56:53 $
+# $Revision: 1.18.1.85 $
 #
 #
 package provide zircon 1.18
 #
 proc busyFlag {net} { $net configure -busy [expr ![$net busy]] }
 #
-proc control_configure {this args} {
-    upvar #0 $this ndata
-    while {![string match {} $args]} {
-	set opt [lindex $args 0]
-	set val [lindex $args 1]
-	switch -glob -- $opt {
-	default { set ndata([string range $opt 1 end]) $val }
-	}
-	set args [lrange $args 2 end]
-    }
-}
+proc control_configure {this args} { confObj $this $args }
 #
-proc control_call {this op args} {
-    upvar #0 $this cdata
-    if [info exists cdata($op)] { return $cdata($op) }
-    return [eval control_$op $this $args]
+#proc control_call {this op args} {
+#    upvar #0 $this cdata
+#    if {[info exists cdata($op)]} {return $cdata($op)}
+#    return [eval control_$op $this $args]
+#}
+#
+proc control_close {this} {
+    $this flagState disabled
+    [$this friends] close
 }
 #
 proc control_pickServer {this srv} { [$this net] changeServer $srv }
@@ -71,105 +66,106 @@ proc control_askServer {this} {
 proc leaveZircon {} {
     set quits 1
     foreach x [Net :: list] {
-	if [$x active] { set quits [expr ($quits & [$x quit])] }
-	if {[$x confChange] &&
-	    [askUser SAVECONF {Save Configuration} \
-	       "You have made changes to the configuration of \
-		netspace \"[$x name].\"\nDo you wish to save them?"]} {
-	    saveCurrent $x
+	if {[$x active]} { set quits [expr ($quits & [$x quit])] }
+	switch {} [$x confChange] {} default {
+	    if {[askUser SAVECONF {Save Configuration} \
+	      "You have made changes to the configuration of \
+	      netspace \"[$x name].\"\nDo you wish to save them?"]} {
+		saveCurrent $x
+	    }
 	}
     }
-    if $quits exit
+    if {$quits} exit
 }
 #
 proc control_redit {this opt} {
-    [$this window].$opt configure -foreground red -activeforeground red
+    set rd [[$this net] setcolour]
+    [$this window].$opt configure -foreground $rd -activeforeground $rd
 }
 #
 proc control_blackit {this opt} {
-    [$this window].$opt configure -foreground black -activeforeground black
+    set bl [[$this net] foreground]
+    [$this window].$opt configure -foreground $bl -activeforeground $bl
 }
 #
 proc flagit {net opt w} {
-    if [$net $opt] {$w.$opt configure -foreground red -activeforeground red }
+    set rd [[$this net] setcolour]
+    if {[$net $opt]} {$w.$opt configure -foreground $rd -activeforeground $rd }
 }
 #
 proc addToConf {net} {
-    set mn .@ctl.helpFrm.info.menu.conf
-    if ![catch {$mn.nets index [$net name]}] return
+    set mn [set ctl [MainControl]].helpFrm.info.menu.conf
+    if {![catch {$mn.nets index [$net name]}]} return
     $mn.nets add cascade -label [$net name] -menu $mn.nets.$net
     menu $mn.nets.$net -tearoff 0
+    $mn.nets.$net add command -label [trans configure] -command "configWin $net"
     $mn.nets.$net add command -label {Save Current} -command "saveCurrent $net"
-    $mn.nets.$net add separator
-    foreach nn {IRC People Channels Info} {
-	$mn.nets.$net add command -label [trans $nn] \
-	  -command "conf$nn $net"
-    }
     switch {} [$net helpService] {} default {
-	.@ctl.helpFrm.help.menu entryconfigure last -state normal
-	set hm .@ctl.helpFrm.help.menu.help
-	if ![winfo exists $hm] { menu $hm -tearoff 0 }
-	.@ctl.helpFrm.help.menu.help add command -label [$net name] \
+	$ctl.helpFrm.help.menu entryconfigure last -state normal
+	set hm $ctl.helpFrm.help.menu.help
+	if {![winfo exists $hm]} { menu $hm -tearoff 0 }
+	$ctl.helpFrm.help.menu.help add command -label [$net name] \
 	  -command "getHelp $net" -state disabled
     }
 }
 #
 proc MainControl {} {
-    global zircon zlayout zCtl DEBUG
-    set zCtl [Window .@ctl -title {Zircon Control Panel}]
-    set ctl [$zCtl name]
-    catch {wm geometry $ctl $zlayout(default,control)}
-    wm resizable $ctl 1 1
-    wm protocol .@ctl WM_DELETE_WINDOW leaveZircon
-    grid columnconfigure .@ctl 0 -weight 1
-    grid [set hf [frame $ctl.helpFrm -borderwidth 0]] -sticky ew
-    set om [makeMB $hf.info "Zircon V$zircon(version)"]
-    $om configure -tearoff 0
-    $om add command -label "About Zircon" -command credits
-    $om add cascade -label [trans configure] -menu $om.conf
-    $om add separator
-    $om add command -label [trans debug] -command zDBGControl \
-      -state [expr {$DEBUG ? {normal} : {disabled}}]
-    $om add separator
-    $om add command -label [trans quit] -command leaveZircon \
-      -accelerator $zircon(meta)-q
-    menu $om.conf -tearoff 0
-    $om.conf add cascade -label {Netspaces} -menu $om.conf.nets
-    menu $om.conf.nets -tearoff 0
-    $om.conf add command -label {Save Current} -command "saveCurrent {}"
-    $om.conf add command -label {Save Layout} -command "saveLayout {}"
-    $om.conf add command -label {Reread rc} -command reread -state disabled
-    foreach x {0 1 2 3} {grid columnconfigure $hf $x -weight 1}
-    netspaceMenu $hf
-    set om [makeMB $hf.help Help]
-    foreach x [glob -nocomplain [file join $zircon(lib) help *]] {
-	set x [file tail $x]
-	set nm [string tolower $x]
-	$om add cascade -label $x -menu $om.$nm
-	menu $om.$nm -tearoff 0 -postcommand "makeHelp $om.$nm $x"
+    if {![winfo exists .@ctl]} {
+	global zircon zlayout zCtl DEBUG
+	set zCtl [Window .@ctl -title {Zircon Control Panel} -resizable {1 1}]
+	set ctl [$zCtl name]
+	catch {wm geometry $ctl $zlayout(default,control)}
+	wm protocol .@ctl WM_DELETE_WINDOW leaveZircon
+	grid columnconfigure .@ctl 0 -weight 1
+	grid [set hf [frame $ctl.helpFrm -borderwidth 0]] -sticky ew
+	set om [makeMB $hf.info "Zircon V$zircon(version)"]
+	$om configure -tearoff 0
+	$om add command -label "About Zircon" -command credits
+	$om add cascade -label [trans configure] -menu $om.conf
+	$om add separator
+	$om add command -label [trans debug] -command zDBGControl \
+	  -state [expr {$DEBUG ? {normal} : {disabled}}]
+	$om add separator
+	$om add command -label [trans quit] -command leaveZircon \
+	  -accelerator $zircon(meta)-q
+	menu $om.conf -tearoff 0
+	$om.conf add cascade -label {Netspaces} -menu $om.conf.nets
+	menu $om.conf.nets -tearoff 0
+	$om.conf add command -label {Save Current} -command "saveCurrent {}"
+	$om.conf add command -label {Save Layout} -command "saveLayout {}"
+	$om.conf add command -label {Reread rc} -command reread -state disabled
+	foreach x {0 1 2 3} {grid columnconfigure $hf $x -weight 1}
+	netspaceMenu $hf
+	set om [makeMB $hf.help Help]
+	foreach x [glob -nocomplain [file join $zircon(lib) help *]] {
+	    set x [file tail $x]
+	    set nm [string tolower $x]
+	    $om add cascade -label $x -menu $om.$nm
+	    menu $om.$nm -tearoff 0 -postcommand "makeHelp $om.$nm $x"
+	}
+	$om add cascade -label "IRC Help Service" -state disabled -menu $om.help
+	grid $hf.spaces $hf.info - $hf.help -sticky ew
+	bind .@ctl <$zircon(meta)-q> leaveZircon
     }
-    $om add cascade -label "IRC Help Service" -state disabled -menu $om.help
-    grid $hf.spaces $hf.info - $hf.help -sticky ew
-    bind .@ctl <$zircon(meta)-q> leaveZircon
+    return .@ctl
 }
 #
-proc Control {this args} {
-    global Ops OType defChan
-    set OType($this) Control
-    initObj $this Control
-    proc $this {args} "eval control_call $this \$args"
+proc Control {args} {
+    global Ops OType defChan zII zNOII
+    set this [makeObj Control $args]
     upvar #0 $this cdata
-    eval $this configure $args
     set net $cdata(net)
-    set ctl [set cdata(window) [switchFrame .@ctl $net [$net name]]]
-    foreach x {0 1 2 3} {grid columnconfigure $ctl $x -weight 1}
+    set ctl [set cdata(window) [switchFrame [MainControl] $net [$net name]]]
+    evenGrid $ctl column 0 3
     $this serverFrame $ctl
 #
     addSeparator $ctl -columnspan 4
 #
     button $ctl.invisible -text [trans invisible] -command "$net toggleFlag invisible"
     $this NNSBuild $ctl Nickname nickname [$net nicks] $net  $ctl.invisible
-    set en [$this NNSBuild $ctl IRCName ircname [$net ircnames] $net -]
+    if {[$net ircIImode]} { set im $zII } { set im $zNOII }
+    button $ctl.ii -command "ntoggleII $net $ctl.ii" -image $im
+    set en [$this NNSBuild $ctl IRCName ircname [$net ircnames] $net $ctl.ii]
     bind $en <ButtonPress-3> "
 	popPalette .@pp$net {} $en [$defChan($net) colour] %X %Y
     "
@@ -179,15 +175,15 @@ proc Control {this args} {
     button $ctl.away -text [trans away] -command "awayPanel $net"
     bind $ctl.away <2> "$net clearAway {}"
 
-    set cdata(friends) [Friends frnd$net -control $this]
-    if [$cdata(friends) menu] {
-	menubutton $ctl.friends -text Friends -menu $ctl.friends.menu
+    set cdata(friends) [Friends -control $this -style [$net friendsStyle]]
+    if {[$cdata(friends) menu]} {
+	menubutton $ctl.friends -text [trans friends] -menu $ctl.friends.menu
 	$cdata(friends) show -padx 4 -pady 5
     } {
-	button $ctl.friends -text Friends -command "$cdata(friends) show" 
-	if [$net showFriends] { $ctl.friends invoke }
+	button $ctl.friends -text [trans friends] -command "$cdata(friends) show" 
+	if {[$net showFriends]} { $ctl.friends invoke }
     }
-    if [info exists Ops(user)] { $this buildUsers $net $ctl 3}
+    if {[info exists Ops(user)]} { $this buildUsers $net $ctl 3}
     set mn [makeMB $ctl.services Services]
     set i 5
     $mn add command -label [trans exec] -command "$net exec"
@@ -256,7 +252,7 @@ proc control_setupChannels {this} {
     set dfc [getDefault defChan $net]
     foreach chan [$net channels] {
 	switch $dfc $chan continue
-	if [$chan menu] {
+	if {[$chan menu]} {
 	    $cm add command -label [$chan name] -command "$chan sendJoin"
 	}
     }
@@ -266,7 +262,7 @@ proc reread {} {
 }
 #
 proc faves {net} {
-    if [winfo exists [set w .@faves$net]] {popup $w ; return}
+    if {[winfo exists [set w .@faves$net]]} {popup $w ; return}
     global defChan
     toplevel $w -class Zircon
     wm title $w Favourites
@@ -282,7 +278,7 @@ proc faves {net} {
     set dfc [getDefault defChan $net]
     foreach chan [$net channels] {
 	switch $dfc $chan continue
-	if [$chan menu] {
+	if {[$chan menu]} {
 	    set fm $w.chList.$chan
 	    set cm [makeMB $fm [$chan name]]
 	    $cm configure -postcommand "favecheck $cm $chan"
@@ -297,7 +293,7 @@ proc faves {net} {
 }
 #
 proc favecheck {menu chan} {
-    if [$chan active] {
+    if {[$chan active]} {
 	foreach e {4 6} { $menu entryconfigure $e -state normal }
 	foreach e {1 3 5} { $menu entryconfigure $e -state disabled }
     } {
@@ -310,7 +306,7 @@ proc keepLeave {chan v} {
     switch {} $v return
     [$chan window].quit.menu add command -label "[prune $v 15]" \
       -command "$chan doLeave {$v}"
-    [$chan net] configure +leaves $v -confChange 1
+    [$chan net] configure +leaves $v +confChange Channels
 }
 #
 proc getLeave {chan} {
@@ -324,7 +320,7 @@ proc keepQuit {ctl v} {
     set net [$ctl net]
     [$ctl window].quit.menu add command -label "[prune $v 15]" \
       -command "$net doQuit {$v}"
-    $net configure +signoffs $v -confChange 1
+    $net configure +signoffs $v +confChange Info
 }
 #
 proc getQuit {ctl} {
@@ -340,20 +336,21 @@ proc control_ircItems {this state} {
     setState $ctl.servers.menu ircSrv $state
     setState $ctl.users.menu ircop $state
     switch $state {
-    normal {$ctl.servers configure -fg red}
-    disabled {$ctl.servers configure -fg black}
+    normal {$ctl.servers configure -fg [$net setcolour]}
+    disabled {$ctl.servers configure -fg [$net foreground]}
     }
 }
 #
-set ch29 {&LOCAL &KILLS &NOTICES &ERRORS &CHANNEL &HASH &NUMERICS &SERVERS}
+set ch29 {&LOCAL &KILLS &NOTICES &ERRORS &CHANNEL &HASH &NUMERICS
+    &SERVERS &SERVICES}
 #
 proc control_add2.9stuff {this} {
     global ch29
     set w [$this window]
     set net [$this net]
     set mn $w.servers.menu
-    if [$mn cget -tearoff] { set ix 1 } { set ix 0 }
-    if ![winfo exists $mn.msgs] {
+    if {[$mn cget -tearoff]} { set ix 1 } { set ix 0 }
+    if {![winfo exists $mn.msgs]} {
 	$mn insert $ix cascade -label [trans messages] -menu $mn.msgs
 	menu $mn.msgs -tearoff 0
 	foreach cn $ch29 {
@@ -370,8 +367,8 @@ proc control_add2.9stuff {this} {
 proc control_del2.9stuff {this} {
     upvar #0 $this cdata
     set mn [$this window].servers.menu
-    if [$mn cget -tearoff] { set ix 1 } { set ix 0 }
-    if [winfo exists $mn.msgs] {
+    if {[$mn cget -tearoff]} { set ix 1 } { set ix 0 }
+    if {[winfo exists $mn.msgs]} {
 	$mn delete [$mn index [trans messages]]
 	destroy $mn.msgs
     }
@@ -379,7 +376,7 @@ proc control_del2.9stuff {this} {
     grid forget $w.wallops 
     grid $w.wallops -row $cdata(smrow) -column 2 -sticky ew
     grid $w.srvmsg -row $cdata(smrow) -column 3 -sticky ew
-    if ![catch {set x [$w.services.menu index Squery]}] {
+    if {![catch {set x [$w.services.menu index Squery]}]} {
 	$w.services.menu delete $x
 	$w.services.menu delete [$w.services.menu index Servlist]
     }
@@ -387,10 +384,10 @@ proc control_del2.9stuff {this} {
 #
 proc control_undernet {this flag} {
     set smn [$this window].servers.menu
-    if [$smn cget -tearoff] { set st 1} { set st 0 }
+    if {[$smn cget -tearoff]} { set st 1} { set st 0 }
     set six [indexHack $smn [trans flags] $st]
     set umn [$this window].users.menu
-    if $flag {
+    if {$flag} {
 	if {$six < 0} {
 	    $smn insert $st command -label [trans flags] \
 	      -command "underflags [$this net]"
@@ -437,7 +434,7 @@ proc control_serverFrame {this ctl} {
     set nf $ctl
     set net [$this net]
     frame $nf.rfr -borderwidth 0
-    label $nf.rfr.restricted -text {RESTRICTED CONNECTION} -fg red    
+    label $nf.rfr.restricted -text {RESTRICTED CONNECTION} -fg [$net setcolour]
     grid $nf.rfr - - - -sticky ew
     set sm [tk_optionMenu $nf.server ${this}(server) {}]
     set srv [$this setupServer $net]
@@ -453,7 +450,7 @@ proc control_serverFrame {this ctl} {
     $nf.port configure -width 4 -highlightthickness 0
     grid $nf.server - $nf.port $nf.quit -sticky ew
     $this showServer $srv
-    if [info exists Ops(server)] { $this buildServers $net $nf 1 0}
+    if {[info exists Ops(server)]} { $this buildServers $net $nf 1 0}
     button $nf.wallops -text Wallops -command "$net toggleFlag wallops"
     button $nf.srvmsg -text SrvMsg -command "$net toggleFlag srvmsg"
     grid $nf.servers - $nf.wallops $nf.srvmsg -sticky ew
@@ -473,13 +470,14 @@ proc control_buildServers {this net ctl row col} {
 		$mn add command -label [trans $cmd] \
 		  -command "serverCmd $net $cmd"
 	    }
-	    if [info exists Ops(ircSrv)] {
+	    if {[info exists Ops(ircSrv)]} {
+		set rd [$net setcolour]
 		foreach cmd $Ops(ircSrv) {
-		  $mn add command -label [trans $cmd] -foreground red \
-		    -activeforeground red -command "serverCmd $net $cmd"
+		  $mn add command -label [trans $cmd] -foreground $rd \
+		    -activeforeground $rd -command "serverCmd $net $cmd"
 		}
 	    }
-	    if ![$net ircop] { setState $ctl.servers.menu ircSrv disabled }
+	    if {![$net ircop]} { setState $ctl.servers.menu ircSrv disabled }
 	}
     }
 }
@@ -512,53 +510,56 @@ proc control_buildUsers {this net ctl row} {
 		    }
 		}
 	    }
-	    if [info exists Ops(ircop)] {
+	    if {[info exists Ops(ircop)]} {
+		set rd [$net setcolour]
 		foreach cmd $Ops(ircop) {
-		    $mn add command -label [trans $cmd] -foreground red \
-		      -activeforeground red -command "userCmd $net $cmd"
+		    $mn add command -label [trans $cmd] -foreground $rd \
+		      -activeforeground $rd -command "userCmd $net $cmd"
 		}
 	    }
-	    if ![$net ircop] { setState $ctl.users.menu ircop disabled }
+	    if {![$net ircop]} { setState $ctl.users.menu ircop disabled }
 	}
     }
 }
 #
 proc control_startup {this} {
     set ctl [$this window]
+    set cl [[$this net] foreground]
     foreach x {wallops invisible srvmsg} {
-	$ctl.$x configure -foreground black -activeforeground black
+	$ctl.$x configure -foreground $cl -activeforeground $cl
     }
 }
 #
-proc nsSubMenu {m name} {
-    set mn [menu $m.n$name -tearoff 0]
-    $mn add command -label [trans load] -command "nsLoad $name 1 {}"
-    $mn add command -label [trans unload] -command "nsUnload $name" -state disabled
-    $mn add command -label [trans clone] -command "nsClone $name"
-    $mn add command -label [trans delete] -command "nsDelete $name"
+proc nsSubMenu {m name w} {
+    set mn [menu $m.$w -tearoff 0]
+    $mn add command -label [trans load] -command "nsLoad [list $name] 1 {}"
+    $mn add command -label [trans unload] -command "nsUnload [list $name]" -state disabled
+    $mn add command -label [trans clone] -command "nsClone [list $name]"
+    $mn add command -label [trans delete] -command "nsDelete [list $name]"
 }
 #
 proc addToNsM {name} {
-    set m .@ctl.helpFrm.spaces.menu
+    set m [MainControl].helpFrm.spaces.menu
     set i 0
-    while {1} {
-	if [catch {set nm [$m entrycget $i -label]}] break
+    while 1 {
+	if {[catch {set nm [$m entrycget $i -label]}]} break
 	if {[string compare $name $nm] < 0} break
 	incr i
     }
-    $m insert $i cascade -label $name -menu $m.n$name
-    nsSubMenu $m $name
+    set wname [newName nsh]
+    $m insert $i cascade -label $name -menu $m.$wname
+    nsSubMenu $m $name $wname
 }
 #
 proc delFromNsM {name} {
-    set m .@ctl.helpFrm.spaces.menu
+    set m [MainControl].helpFrm.spaces.menu
     set i 0
-    while {1} {
-	if [catch {set nm [$m entrycget $i -label]}] return
+    while 1 {
+	if {[catch {set nm [$m entrycget $i -label]}]} return
 	switch -- $name $nm break
 	incr i
     }
-    destroy $m.n$name
+    destroy [$m entrycget $i -menu]
     $m delete $i
 }
 #
@@ -567,7 +568,7 @@ proc netspaceMenu {w} {
     set pf1 {}
     set pf2 {}
     [set om [makeMB $w.spaces Netspaces]] configure -tearoff 0
-    if ![file exists [set ns [file join $zircon(prefdir) netspaces]]] {
+    if {![file exists [set ns [file join $zircon(prefdir) netspaces]]]} {
 	$w.spaces configure -state disabled
     } {
 	foreach x [lsort [glob -nocomplain [file join $ns *]]] { addNS $om $x }
@@ -575,14 +576,21 @@ proc netspaceMenu {w} {
     }
 }
 #
-proc addToNM {name} { addNS .@ctl.helpFrm.spaces.menu $name }
+proc addToNM {name} { addNS [MainControl].helpFrm.spaces.menu $name }
 #
 #proc delFromNM {net} {
-#    .@ctl.helpFrm.spaces.menu delete [.@ctl.helpFrm.spaces.menu index $net]
+#    .@ctl.helpFrm.spaces.menu delete [[MainControl].helpFrm.spaces.menu index $net]
 #}
 #
-proc setUnload {net state} {
-    .@ctl.helpFrm.spaces.menu.n$net entryconfigure 1 -state $state
+proc setUnload {name state} {
+    set m [MainControl].helpFrm.spaces.menu
+    set i 0
+    while 1 {
+	if {[catch {set nm [$m entrycget $i -label]}]} return
+	switch -- $name $nm break
+	incr i
+    }
+    [$m entrycget $i -menu]  entryconfigure 1 -state $state
 }
 #
 proc addNS {om x} {
@@ -590,8 +598,9 @@ proc addNS {om x} {
     switch -glob -- $fn {
     *.bak - *.tmp {}
     default {
-	    $om add cascade -label $fn -menu $om.n$fn
-	    nsSubMenu $om $fn
+	    set w [newName nsh]
+	    $om add cascade -label $fn -menu $om.$w
+	    nsSubMenu $om $fn $w
 	}
     }
 }
@@ -602,7 +611,7 @@ proc control_flagState {this state} {
     set ctl [$this window]
     set net [$this net]
     switch {} [$net helpService] {} default {
-	set hm .@ctl.helpFrm.help.menu.help
+	set hm [MainControl].helpFrm.help.menu.help
 	set ix [$hm index [$net name]]
 	$hm entryconfigure $ix -state $state
     }
@@ -615,6 +624,7 @@ proc control_flagState {this state} {
 	    $ctl.$x configure -state normal
 	}
     }
+    [$this friends] flagState $state
 }
 #
 proc control_setQuit {this txt cmd} {
@@ -638,20 +648,51 @@ proc control_openState {this} {
     return [[$this window].quit cget -state]
 }
 #
+proc control_delete {this} {
+    deleteFrame [MainControl] [$this net]
+    [$this friends] delete
+    uplevel #0 unset $this
+}
+#
 proc control_flagSet {this flg val} {
-    if $val {
-	set cl red
+    if {$val} {
+	set cl setcolour
     } {
-	set cl black
+	set cl foreground
     }
+    set cl [[$this net] $cl]
     [$this window].$flg configure -foreground $cl -activeforeground $cl
 }
 #
 proc control_restricted {this val} {
     set net [$this net]
-    if $val {
+    if {$val} {
 	grid [$this window].rfr.restricted -sticky ew
     } {
 	grid forget [$this window].rfr.restricted
     }	
 }
+#
+proc ntoggleII {net win} {
+    global zII zNOII
+    if {[$net ircIImode]} {
+	set im $zNOII
+	set val 0
+    } {
+	set val 1
+	set im $zII
+    }
+    $net configure -ircIImode $val
+    $win configure -image $im
+    foreach y {channels messages notices} {
+	foreach x [$net $y] {
+	    if {[$x ircIImode] != $val} {
+		if {[$x active]} {
+		    toggleII $x [$x window].cmd.ii
+		} {
+		    $x configure -ircIImode $val
+		}
+	    }
+	}
+    }
+}
