@@ -1,21 +1,21 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 1997/07/08 11:27:58 $
-# $Revision: 1.18.1.32 $
+# $Date: 1998/02/26 12:23:14 $
+# $Revision: 1.18.1.46 $
 #
 package provide zircon 1.18
 #
 #   Handle IRC cmds
 #
 proc ctcpAnswer {net usr nk cp} {
-    handleOn [$usr net] CTCPREPLY [list $nk $cp]
+    handleOn $net CTCPREPLY [list $nk $cp]
     set chn {}
     foreach x [$usr channels] {
 	if {[$x active] && [[$x wid] visible]} {lappend chn $x}
     }
     regsub -all "\[\x01-\x1f\]" $nk {} nk
     switch {} $chn {
-	mkInfoBox $net CTCP .@ctcp$usr {CTCP Reply} "CTCP Reply from $nk:\n$cp"
+	tellInfo $net {CTCP Reply} "CTCP Reply from $nk:\n$cp" CTCP
     } default {
 	foreach x $chn {
 	    $x addText @CTCP "*** CTCP Reply from $nk: $cp"
@@ -28,16 +28,16 @@ proc ircERROR {net prefix param pargs} { $net error $prefix $param $pargs }
 proc ircPONG {net prefix param pargs} { $net configure -pinged 0 }
 #
 proc mungNotice {msg} {
-    if [regexp \
+    if {[regexp \
       {Received KILL message for ([^ ]+). From ([^ ]+) Path: ([^ ]+) (.*)} \
-      $msg match user from path rest] {
+      $msg match user from path rest]} {
 	return "*** KILL from $from for $user $rest"
     }
     return $msg
 }
 #
 proc pingVal {val} {
-    if [regexp "^PING\[ \t\]+(\[0-9\]+).*" $val m t] {
+    if {[regexp "^PING\[ \t\]+(\[0-9\]+).*" $val m t]} {
 	return "[zping $t] secs"
     }
     return {Corrupt PING value}
@@ -45,11 +45,11 @@ proc pingVal {val} {
 #
 proc ircNOTICE {net prefix param pargs} {
     set nkinfo [mungPrefix $net $prefix]
-    if [ignoreSet [lindex $nkinfo 3] notices] {ditchPrefix $nkinfo ; return}
+    if {[ignoreSet [lindex $nkinfo 3] notices]} {ditchPrefix $nkinfo ; return}
     set id [find [set chan [lindex $pargs 0]] $net]
     switch {} [lindex $nkinfo 2] {
-	if [$id active] {
-	    $id addText {} "-$prefix- $param"
+	if {[$id active]} {
+	    $id addText {} "-[string range $prefix 1 end]- $param"
 	} {
 	    switch nil $id {
 	        $net inform [mungNotice $param]
@@ -66,7 +66,7 @@ proc ircNOTICE {net prefix param pargs} {
   	    }
 	    switch {} [set param $a$b] return
 	}
-	if [$id isa Channel] {
+	if {[$id isa Channel]} {
 	    $id addText $usr "-$nk- $param"
 	} \
 	elseif {![string compare nil [set id [Notice :: find $nk $net]]] &&
@@ -75,10 +75,11 @@ proc ircNOTICE {net prefix param pargs} {
 		$net inform "Notice from $nk at [getDate] : $param"
 	    } {
 		set id [Notice :: make $net $nk]
-		$id addText {} "[getDate]\n$param"
+		if {[$id timestamp]} {set ts {}} {set ts "[getDate]\n"}
+		$id addText {} "$ts$param"
 	    }
 	} {
-	    if ![$id active] {$id show}
+	    if {![$id active]} {$id show}
 	    $id addText $usr $param
 	}
     }
@@ -90,7 +91,7 @@ proc ircMODE {net prefix param pargs} {
     global userFlags
     set chan [lindex $pargs 0]
     switch nil [set id [Channel :: find $chan $net]] {
-	if [me $chan $net] {
+	if {[me $chan $net]} {
 	    switch {} [set md [lindex $pargs 1]] {set md $param}
 	    foreach m [split $md {}] {
 		switch -- $m {
@@ -102,10 +103,9 @@ proc ircMODE {net prefix param pargs} {
 	}
 	return
     }
-    $id mode [lrange $pargs 1 end]
+    $id mode [set pd [lrange $pargs 1 end]]
     $id optText MODE "*** Mode change \"[string trim \
-      [join [lrange $pargs 1 end]]]\" on channel $chan by\
-      [lindex [mung1Prefix $net $prefix] 0]"
+      [join $pd]]\" on channel $chan by [lindex [mung1Prefix $net $prefix] 0]"
 }
 #
 proc ircPRIVMSG {net prefix param pargs} {
@@ -122,26 +122,28 @@ proc ircPRIVMSG {net prefix param pargs} {
 	}
     }
     regsub -all "\[\x01-\x1f\]" "<[set nk [$usr name]]>" {} pfx
-    if [me $chan $net] {
-	if [ignoreSet $ign notes] return
+    if {[me $chan $net]} {
+	if {[ignoreSet $ign notes]} return
 	switch nil [set where [Message :: find $nk $net]] {
 	    global zircon
-	    if [$net busy] {
+	    if {[$net busy]} {
 		$net queue "NOTICE $nk :[$net busymsg]"
 		$net inform "Message from $nk at [getDate] : $param"
 	    } {
 		handleOn $net POPUP [list $nk]
-		[Message :: make $net $nk] addText $usr "[getDate]\n$pfx $param"
+		set id [Message :: make $net $nk]
+		if {[$id timestamp]} {set ts {}} {set ts "[getDate]\n"}
+		$id addText $usr "$ts$pfx $param"
 	    }
 	    ditchPrefix $nkinfo
 	    return
 	} default {
 	    $where show
-	    if ![$where isJoined $usr] {$where addUser $usr 0 0}
+	    if {![$where isJoined $usr]} {$where addUser $usr 0 0}
 	}
 	set chan [$usr lname]
     } {
-	if [ignoreSet $ign public] return
+	if {[ignoreSet $ign public]} return
 	set where [Channel :: find $chan $net]
     }
     switch nil $where {
@@ -153,25 +155,40 @@ proc ircPRIVMSG {net prefix param pargs} {
 	set pt [lindex $p 0]
 	if {[regexp -nocase [lindex $pt 0] $prefix] && \
 	  [regexp [lindex $pt 1] $param]} {
-	    if [catch {uplevel #0 [lindex $p 1]} msg] {
+	    uplevel #0 set 0 [list $prefix]
+	    uplevel #0 set 1 [list $chan]
+	    if {[catch {uplevel #0 [lindex $p 1]} msg]} {
 		tellError {} {Pattern Command Error} \
 		  "Error when executing pattern command \"[lindex $p 1]\" : $msg"
 	    }
+	    uplevel #0 unset 0 1
 	}
     }
     ditchPrefix $nkinfo
 }
 #
 proc ircJOIN {net prefix param pargs} {
-    if ![regexp "^(.*)\a(\[ov\]+)\$" $param m chan ov] {
-	set chan $param
+    switch {} $param {
+	set chan $pargs
 	set ov {}
+    } default {
+	if {![regexp "^(.*)\a(\[ov\]+)\$" $param m chan ov]} {
+	    set chan $param
+	    set ov {}
+        }
     }
-    if [notAnon $chan $prefix] {
+    if {[notAnon $chan $prefix]} {
 	set nkinfo [mungPrefix $net $prefix]
-	if [lindex $nkinfo 1] { [Channel :: make $net $chan] show } {
-	    [Channel :: find $chan $net ] doJoin [lindex $nkinfo 0] \
-	      [lindex $nkinfo 2] $prefix $ov
+	if {[lindex $nkinfo 1]} {
+	    [set chn [Channel :: make $net $chan]] show
+	    $chn handleOV $ov [lindex $nkinfo 0]
+	} {
+	    set usr [lindex $nkinfo 0]
+	    set nm [lindex $nkinfo 2]
+	    switch nil [set frd [Friend :: find [$usr name] $net]] {} default {
+		$frd appear $nm
+	    }
+	    [Channel :: find $chan $net ] doJoin $usr $nm $prefix $ov
 	}
 	ditchPrefix $nkinfo
     }
@@ -180,7 +197,7 @@ proc ircJOIN {net prefix param pargs} {
 #
 proc ircNICK {net prefix param pargs} {
     set usr [lindex [set nkinfo [mungPrefix $net $prefix]] 0]
-    if [lindex $nkinfo 1] { $net configure -nickname $param } \
+    if {[lindex $nkinfo 1]} { $net configure -nickname $param } \
     elseif {[string compare nil [set orig [User :: find $param $net]]] &&
 	[string compare $usr $orig]} {
 	$usr substitute $orig
@@ -207,9 +224,9 @@ proc notAnon {c p} {
 #
 proc ircPART {net prefix param pargs} {
     set chan [Channel :: find [set chn [lindex $pargs 0]] $net]
-    if [notAnon $chn $prefix] {
+    if {[notAnon $chn $prefix]} {
 	set nkinfo [mungPrefix $net $prefix]
-	if [lindex $nkinfo 1] {$chan delete} {
+	if {[lindex $nkinfo 1]} {$chan delete} {
 	    set usr [lindex $nkinfo 0]
 	    set msg {}
 	    switch {} $param {} default { set msg " : ($param)" }
@@ -227,7 +244,7 @@ proc netsplit {string} {
 }
 #
 proc ircQUIT {net prefix param pargs} {
-    if ![lindex [set nkinfo [mungPrefix $net $prefix]] 1] {
+    if {![lindex [set nkinfo [mungPrefix $net $prefix]] 1]} {
 	set nk [[set usr [lindex $nkinfo 0]] name]
 	if {![$net nosplit] && [netsplit $param]} {
 	    $usr split $param
@@ -238,15 +255,15 @@ proc ircQUIT {net prefix param pargs} {
 	    }
 	    $usr off
 
-	    if [set ti [listmember [$net toInfo] SIGNOFF]] {
+	    if {[set ti [listmember [$net toInfo] SIGNOFF]]} {
 		$net display @QUIT "*** Signoff: $nk ($param)"
 	    }
 	    set lnk [$usr lname]
 	    foreach x {channels messages notices chats} {
 		foreach id [$net $x] {
-		    if [$id active] {
-			if [$id isJoined $usr] {
-			    if !$ti {$id optText QUIT "*** Signoff: $nk ($param)"}
+		    if {[$id active]} {
+			if {[$id isJoined $usr]} {
+			    if {!$ti} {$id optText QUIT "*** Signoff: $nk ($param)"}
 			    $id killUser $usr
 		        } {
 		            switch -- [$id lname] $lnk {
@@ -268,11 +285,17 @@ proc ircKICK {net prefix param pargs} {
     set nk [[set who [User :: make $net [lindex $pargs 1]]] name]
     set kicker [[lindex $nkinfo 0] name]
     set id [Channel :: find $chan $net]
-    if [$net me $who] {
+    if {[$net me $who]} {
 	$id optText KICKME "*** You have been kicked off channel $chan by $kicker ($param)"
-	if [askUser KICKED "Kicked from $chan" \
+	if {[askUser KICKED "Kicked from $chan" \
 	  "You have been kicked off channel $chan by $kicker\
-($param). Do you want to rejoin?"] {$id rejoin {}} {$id delete}
+($param). Do you want to rejoin?"]} {
+	# the next code is in case the channel window was closed before
+	# answering so we need to find the id again.
+	    [Channel :: make $net $chan] rejoin
+	} {
+	    catch {$id delete}
+	}
     } {
 	$id optText KICK \
 	  "*** $nk has been kicked off channel $chan by $kicker ($param)"
@@ -283,9 +306,9 @@ proc ircKICK {net prefix param pargs} {
 }
 #
 proc ircINVITE {net prefix param pargs} {
-    if ![ignoreSet [lindex [set nkinfo [mungPrefix $net $prefix]] 3] invites] {
+    if {![ignoreSet [lindex [set nkinfo [mungPrefix $net $prefix]] 3] invites]} {
 	set name [[lindex $nkinfo 0] name]
-	if [askUser {} Invitation  "$name invites you to channel $param."] {
+	if {[askUser {} Invitation  "$name invites you to channel $param."]} {
 	    set chid [Channel :: make $net $param]
 	    catch {destroy .@kick$chid}
 	    $chid sendJoin {}
@@ -300,8 +323,8 @@ proc ircKILL {net prefix param pargs} {
     [set who [User :: make $net [lindex $pargs 0]]] off
     $who ref
     set nk [$who name]
-    if [$net me $who] {
-	tellInfo Killed "You have been killed by [lindex $nkinfo 0] ($param)"
+    if {[$net me $who]} {
+	tellInfo $net Killed "You have been killed by [lindex $nkinfo 0] ($param)" KILL
     } {
 	foreach x {channels notices messages} {
 	    foreach id [$net $x] {
@@ -349,17 +372,15 @@ proc ircNUM {net number pargs} {
 #	returns : {user object, me?, user@host, ignores}
 #
 proc mungPrefix {net prefix} {
-    if ![regexp {^:([^!]*)!(.*)} $prefix m1 nk nm] {
-	set nk [string range $prefix 1 end]
-	set nm {}
-	return [list nil 0 $nm {}]
+    if {![regexp {^:([^!]+)!(.*)} $prefix m1 nk nm]} {
+	return [list nil 0 {} {}]
     }
     [set usr [User :: make $net $nk $nm]] ref
     return [list $usr [$net me $usr] $nm [z_ignore $usr $nm]]
 }
 #
 proc mung1Prefix {net prefix} {
-    if ![regexp {:([^!]*)!(.*)} $prefix m1 nk nm] {
+    if {![regexp {^:([^!]+)!(.*)} $prefix m1 nk nm]} {
 	set nk [string range $prefix 1 end]
 	set nm {}
     }
