@@ -1,39 +1,37 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Info.tcl,v $
-# $Date: 1997/06/09 12:02:55 $
-# $Revision: 1.18.1.20 $
+# $Date: 1998/03/02 12:10:45 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
 # Build a Zircon Information Window.
 #
 proc MainInfo {} {
-    global zlayout zInfo
-    set zInfo [Window .@inf -title {Zircon Information}]
-    set w [$zInfo name]
-    catch {wm geometry .@inf $zlayout(default,info)}
-    wm resizable .@inf 1 1
-    grid columnconfigure .@inf 0 -weight 1 -minsize 50
+    if {![winfo exists .@inf]} {
+	global zlayout zInfo
+	set zInfo [Window .@inf -title {Zircon Information} -resizable {1 1}]
+	set w [$zInfo name]
+	catch {wm geometry .@inf $zlayout(default,info)}
+        grid columnconfigure .@inf 0 -weight 1 -minsize 50
+    }
+    return .@inf
 }
 #
-proc Info {name args} {
-    switch :: $name {
-	return [eval Info_[lindex $args 0] [lrange $args 1 end] ]
-    }
-    global BF Fg Bg Ft Bl OType defChan zInfo
-    initObj $name Channel Info
-    proc $name {args} "eval info_call $name \$args"
-    set OType($name) Info
+proc Info {args} {
+    global BF Fg Bg Ft Bl OType defChan zInfo zII zNOII
+    set name [makeObj {Channel Info} $args]
     upvar #0 $name idata
-    set net [set idata(net) [lindex $args 1]]
-    set w [switchFrame .@inf $name [$net name] -handles]
+    set net $idata(net)
+    set w [switchFrame [MainInfo] $name [$net name] -handles]
     set df [getDefault defChan $net]
-    $name configure -hpos end -open [$idata(net) popInfo] \
+    $name configure -hpos 0 -open [$idata(net) popInfo] \
       -close [$df close] -jump 1 -quiet 0 -draw 0 \
       -msg [$df msg] -actionmode 0 \
       -actions 0 -patterns {} -logfile {} -history [$df history] \
       -closetime [$df closetime] -log {} -menu 0 -join 0 \
-      -ops {} -keep 1 -monitor 0 -wid $zInfo -window $w 
+      -ops {} -keep 1 -monitor 0 -wid $zInfo -window $w \
+      -ircIImode [$net ircIImode]
     grid rowconfigure $w 0 -weight 1
     grid columnconfigure $w 0 -weight 1
     frame $w.cl -borderwidth 0
@@ -43,14 +41,13 @@ proc Info {name args} {
       -relief sunken -state disabled
     button $w.cl.clear -text [trans clear] -command "$name clear" -width 5 \
       -borderwidth 2 -highlightthickness 2 -pady 0
-    grid $w.cl.cmd -row 0 -column 0 -sticky ew
-    grid $w.cl.hs -row 1 -column 0 -sticky ew
-    grid $w.cl.clear -row 0 -column 1 -rowspan 2
-    if [$net command] { grid $w.cl -row 1 -columnspan 2 -sticky ew }
+    grid $w.cl.cmd $w.cl.clear -sticky ew
+    grid $w.cl.hs - -sticky ew
+    if {[$net command]} { grid $w.cl -row 1 -columnspan 2 -sticky ew }
     doInfoBindings $w.cl.cmd $name
     bind $w.cl.cmd <Return> "$name doCmd %W"
     set idata(text) [set oft $w.info]
-    scrollbar $w.vscroller -command "doScroll $oft"
+    scrollbar $w.vscroller -command "$oft yview"
     text $oft -height 10 -width 80 \
       -yscrollcommand "setScroll $name $oft $w.vscroller" -borderwidth 2
     rebind $oft $idata(net)
@@ -68,6 +65,8 @@ proc Info {name args} {
     return $name
 }
 #
+proc info_delete {this} { mcnDelete $this ITO[$this net] info }
+#
 proc info_onShow {this} { }
 #
 proc info_clear {this} {
@@ -76,31 +75,33 @@ proc info_clear {this} {
 }
 #
 proc info_send {this string args} {
-    bell
+    if {[[$this net] raw]} {
+	$this configure -hpos 0
+	$this addText {} ":>$string"
+	$this addHist $string
+	[$this net] sendRaw $string
+    } { bell }
 }
 #
-proc info_doCmd {this w} {
-    set net [$this net]
-    if [$net raw] {
-	set line [$w get]
-	$this configure -hpos end
-	$this addText {} ":>$line"
-	$net sendRaw $line
-	$w delete 0 end
+proc info_command {this on} {
+    upvar #0 $this idata
+    if {$on} {
+	grid $idata(window).cl
     } {
-	$net doMisc2 $this $w
+	grid forget $idata(window).cl
     }
 }
 #
-proc info_call {this op args} {
+proc info_doCmd {this w} { [$this net] doMisc2 $this $w }
+#
+proc info_call {this op pars} {
     upvar #0 $this idata
     switch $op {
-    lname -
-    name { return $this }
+    lname { return $this }
     crypt { return {} }
     control { return [$idata(net) control] }
     command {
-	    if [lindex $args 0] {
+	    if {[lindex $pars 0]} {
 		grid $idata(window).cl
 	    } {
 		grid forget $idata(window).cl
@@ -109,11 +110,9 @@ proc info_call {this op args} {
 	}
     users { return [$idatda(net) users] }
     }
-    if [info exists idata($op)] { return $idata($op) }
-    switch {} [info procs info_$op] {
-	return [eval channel_call $this $op $args]
-    }
-    return [eval info_$op $this $args]
+    if {[info exists idata($op)]} { return $idata($op) }
+    switch {} [info procs info_$op] {return [objCall channel $this $op $pars]}
+    return [eval info_$op $this $pars]
 }
 #
 proc info_popup {this} {
@@ -135,9 +134,12 @@ proc info_insert {this text} {
 	$ent insert insert $text
 	tkEntrySeeInsert $ent
     }
-    $this configure -hpos end
 }
 #
 proc info_flagState {this state} {
     [$this window].cl.cmd configure -state $state
 }
+#
+proc info_close {this} {
+    $this flagState disabled
+}
