@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Message.tcl,v $
-# $Date: 1997/07/18 08:10:23 $
-# $Revision: 1.18.1.26 $
+# $Date: 1998/03/03 09:21:30 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -19,25 +19,25 @@ proc Message {name args} {
     return $id
 }
 #
-proc message_call {this op args} {
+proc message_call {this op pars} {
     switch {} [info procs message_$op] {
-	return [eval channel_call $this $op $args]
+	return [objCall channel $this $op $pars]
     }
-    return [eval message_$op $this $args]
+    return [eval message_$op $this $pars]
 }
 #
 proc makeMessage {chan net} {
     global defMsg
     set this [objName Message]
-    proc $this {args} "eval message_call $this \$args "
+    proc $this {op args} "message_call $this \$op \$args "
     initObj $this Channel Message
     upvar #0 $this mdata MTO$net MTO
     switch *default* [set lchan [string tolower $chan]] {} default {
 	[User :: make $net $chan] join $this
     }
-    if [catch {set def $defMsg($net)}] {
+    if {[catch {set def $defMsg($net)}]} {
 	global defaultNet defChan
-	if [catch {set def $defMsg($defaultNet)}] {
+	if {[catch {set def $defMsg($defaultNet)}]} {
 	    set def $defChan($defaultNet)
 	}
 	set b 0
@@ -51,6 +51,7 @@ proc makeMessage {chan net} {
 	name	$chan \
 	lname	$lchan \
 	net	$net \
+	ircIImode [$net ircIImode] \
     ]
     $net register messages $this 
     set MTO($lchan) $this
@@ -80,7 +81,7 @@ proc message_nickChange {this usr nnk} {
 #
 proc message_nChange {this nnk} {
     set net [$this net]
-    if [$this active] {
+    if {[$this active]} {
 	[$this wid] setIcon $this $nnk
 	switch nil [set usr [User :: find [$this name] $net]] {} default {
 	    switch {} [set id [$usr id]] {} default { set id " ($id)"}
@@ -91,9 +92,9 @@ proc message_nChange {this nnk} {
     set ln [string tolower $nnk]
     unset MTO($cdata(lname))
     set MTO($ln) $this
-    array set cdata [list
-	lname	$ln
-	name	$nnk
+    array set cdata [list\
+	lname	$ln \
+	name	$nnk \
     ]
 }
 #
@@ -109,7 +110,7 @@ proc Message_make {net nk} {
     set nk [$net trimNick [cleanup $nk]]
     set usr [User :: make $net $nk]
     set ln [string tolower $nk]
-    if [info exists MTO($ln)] { set id $MTO($ln) } {
+    if {[info exists MTO($ln)]} { set id $MTO($ln) } {
 	set id [$net eval [list Message $nk]]
     }
     $id configure -crypt [$usr crypt]
@@ -146,12 +147,19 @@ proc message_awayMsg {this msg} {
     upvar #0 $this mdata
     switch -- $mdata(away) $msg {} default {
 	set mdata(away) $msg
-	if [$this active] {$this addText {} "*** [$this name] is away : $msg"}
+	if {[$this active]} {$this addText {} "*** [$this name] is away : $msg"}
     }
 }
 #
 proc message_leave {this} {
     set chan [$this name]
-    if [askUser LEAVE "Leaving conversation with $chan" \
-      "Really close conversation with $chan?"] { $this delete }
+    if {[askUser LEAVE "Leaving conversation with $chan" \
+      "Really close conversation with $chan?"]} { $this delete }
+}
+#
+proc message_heal {this} {
+    if {[$this active]} {
+	$this flag normal
+	$this addText {} "*** netsplit : [$this name] may have left IRC."
+    }
 }
