@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1997/07/18 08:01:29 $
-# $Revision: 1.18.1.104 $
+# $Date: 1998/03/03 09:28:16 $
+# $Revision: 1.18.1.130 $
 #
 package provide zircon 1.18
 #
@@ -11,11 +11,10 @@ set znetList {}
 proc Net {name args} {
     global XTO defaultNet
     switch $name :: {return [eval Net_[lindex $args 0] [lrange $args 1 end] ]}
-    set this [objName Net]
+    set this [makeObj Net $args]
     upvar #0 $this ndata
     set XTO([string tolower $name]) $this
-    initObj $this Net
-    if [info exists defaultNet] {
+    if {[info exists defaultNet]} {
 	array set ndata [array get $defaultNet]
 	array set ndata {
 	    channels	{}
@@ -26,21 +25,49 @@ proc Net {name args} {
 	    friends	{}
 	    servers	{}
 	    services	{}
+	    info	{}
+	    control	{}
+	    listid	{}
 	}
     }
-    proc $this {args} "eval net_call $this \$args"
-    set OType($this) Net
-    set ndata(name) $name
-    eval $this configure $args
+    foreach x {Get Send Resume Offer AChat} {
+	uplevel #0 trace variable $x$this u unsetSGO
+    }
+    array set ndata "name $name"
     uplevel #0 lappend znetList $this
     return $this
 }
 #
+proc net_call {this op pars} {
+    upvar #0 $this ndata
+    switch $op active {switch {} $ndata(sock) {return 0} ; return 1 }
+    if {[info exists ndata($op)]} {return $ndata($op)}
+    uplevel #0 set currentNet $this
+    return [eval net_$op $this $pars]
+}
+#
+proc net_channelList {this chn} {
+    $this configure -allChannels {} -showlist 0
+    [set lst [$this listid]] show
+    switch {} $chn {} default {
+	$lst doit $chn
+	$this configure -showlist 1
+    }
+}
+#
+proc net_irc321 {this args} { [$this listid] irc321 }
+#
+proc net_irc322 {this prefix param pargs} {
+    [$this listid] irc322 $prefix $param $pargs
+}
+#
+proc net_irc323 {this prefix param pargs} { [$this listid] process }
+#
 proc net_eval {this cmd} {
     global currentNet
     set sc $currentNet
     set currentNet $this
-    if [catch {set res [eval $cmd]} msg] {
+    if {[catch {set res [eval $cmd]} msg]} {
 	set currentNet $sc
 	error $msg
     }
@@ -50,7 +77,7 @@ proc net_eval {this cmd} {
 #
 proc net_trimNick {this nk} {
     upvar #0 $this ndata
-    if $ndata(nicksize) {
+    if {$ndata(nicksize)} {
 	set uh {}
 	regexp {(.*)(@.*)} $nk m nk uh
 	return [string range $nk 0 [expr $ndata(nicksize) - 1]]$uh
@@ -62,9 +89,8 @@ proc net_me {this usr} {switch $usr [$this myid] {return 1} ; return 0}
 #
 proc net_configure {this args} {
     upvar #0 $this ndata
-    while {![string match {} $args]} {
-	set name [string range [set opt [lindex $args 0]] 1 end]
-	set val [lindex $args 1]
+    foreach {opt val} $args {
+	set name [string range $opt 1 end]
 	switch -glob -- $opt {
 	-toInfo -
 	-noconfirm {
@@ -72,7 +98,7 @@ proc net_configure {this args} {
 		foreach x $val {lappend ndata($name) [string toupper $x]}
 	    }
 	-startup {
-		if ![set ndata(startup) $val] { [$this control] startup	}
+		if {![set ndata(startup) $val]} { [$this control] startup	}
 	    }
 	-nickname { $this setNickname $val }
 	-ircname { 
@@ -84,7 +110,7 @@ proc net_configure {this args} {
 	-ircop {
 		set ndata(ircop) $val
 		[$this control] ircItems [expr {$val ? {normal} : {disabled}}]
-		if $val {
+		if {$val} {
 		    set ndata(wallops) 1
 		    set ndata(srvmsg) 1
 		} {
@@ -136,7 +162,6 @@ proc net_configure {this args} {
 	    }
 	default { set ndata($name) $val }
 	}
-	set args [lrange $args 2 end]
     }
 }
 #
@@ -171,7 +196,7 @@ proc net_finfo {this} {
 proc net_setupUsers {this} {
     set frnd [$this finfo]
     foreach frd [$this friends] {
-	if [$this friendsOn] { $frd configure -notify 1 }
+	if {[$this friendsOn]} { $frd configure -notify 1 }
 	if {![$this friendsOn] || [$frd ison]} { $frnd add $frd}
     }
 }
@@ -198,14 +223,6 @@ proc net_warn {this txt} { [$this info] addText @WARN "*** $txt" }
 #
 proc net_errmsg {this txt} { [$this info] addText @ERROR "*** $txt" }
 #
-proc net_call {this op args} {
-    upvar #0 $this ndata
-    switch $op active {switch {} $ndata(sock) {return 0} ; return 1 }
-    if [info exists ndata($op)] {return $ndata($op)}
-    uplevel #0 set currentNet $this
-    return [eval net_$op $this $args]
-}
-#
 proc net_host {this} {
     upvar #0 ${this}(hostid) hostid
     switch nil $hostid {return {}}
@@ -241,8 +258,9 @@ proc net_quit {this} {
 proc net_show {this} {
     upvar #0 $this ndata
     switch {} $ndata(info) {
-	set ndata(info) [Info info$this -net $this]
-	set ndata(control) [Control ctl$this -net $this]
+	set ndata(info) [Info -net $this]
+	set ndata(control) [Control -net $this]
+	set ndata(listid) [List -net $this]
     }
     $this flagControl disabled
     $this setupUsers
@@ -255,7 +273,7 @@ proc net_startIRC {this srv args} {
     $this show
     set server [$srv host]
     $this configure -ircop 0 -msgQueue {} -msgQTag {} -sysQueue {} \
-      -hostid $srv -motdSeen 0
+      -hostid $srv -motdSeen 0 closing {}
     set ctl [$this control]
     set ost [$ctl openState]
     set ports [$srv port]
@@ -264,13 +282,21 @@ proc net_startIRC {this srv args} {
 	   set ports $pt
 	}
     }
+    set enc [$srv encoding]
     foreach port $ports {
 	$ctl showServer $srv $port
 	$this inform "Connecting to port $port of server $server"
 	update idletasks
 	$this slow
 	set ndata(sock) {}
-	if {[catch {socket -async $server $port} sock]} {
+	set scmd socket
+	foreach x {myaddr myport } {
+	    switch {} $ndata($x) {} default {
+		append scmd " -$x $ndata($x)"
+	    }
+	}
+	append scmd " -async $server $port"
+	if {[catch {eval $scmd} sock]} {
 	    $this errmsg "Cannot connect to port $port of server $server ($sock)"
 	    set ndata(sock) {}
 	    $this fast
@@ -279,25 +305,30 @@ proc net_startIRC {this srv args} {
 	}
 	$this fast
 	fileevent $sock writable \
-	  "sconf $sock ; $this cCheck $sock ; $this afterCon $sock"
+	  "sconf $sock [list $enc]; $this cCheck $sock ; $this afterCon $sock"
 	$ctl setQuit abort "$this abort $sock"
 	set connected($this) 0
 	vwait connected($this)
-	if [set res [expr {$connected($this) != 2}]] {
+	if {[set res [expr {$connected($this) < 2}]]} {
 	    $ctl setQuit close "$this quit"
 	    return $res
 	}
 	$ctl setQuit open "$ctl open"
 	$ctl setOpen $ost
-	retitleFrame .@ctl $this [$this name] 1
-	retitleFrame .@inf [$this info] [$this name] 1
+	if {$connected($this) == 2} {
+	    retitleFrame [MainControl] $this [$this name] 1
+	    retitleFrame [MainInfo] [$this info] [$this name] 1
+	} {
+	    retitleFrame [MainControl] $this [$this name]
+	    retitleFrame [MainInfo] [$this info] [$this name]
+	}
     }
     return 0
 }
 #
 proc net_abort {this sock} {
     close $sock
-    uplevel #0 set connected($this) 2
+    uplevel #0 set connected($this) 3
 }
 #
 proc net_cCheck {this sock} {
@@ -320,8 +351,8 @@ proc net_afterCon {this sock} {
     set STN($sock) $this
     set ndata(sock) $sock
     set srv $ndata(hostid)
-    switch nil $srv {$this closeSock $sock ; return 0}
-    if ![info exists host] {set host [info hostname]}
+    switch nil $srv {$this closeSock {} ; return 0}
+    if {![info exists host]} {set host [info hostname]}
     set server [$srv host]
     set passwd [$srv passwd]
     foreach ln [$srv script] { puts -nonewline $sock "$ln\n" }
@@ -329,11 +360,11 @@ proc net_afterCon {this sock} {
     switch {} $passwd {} default {$this qSend PASS :$passwd}
     $this qSend USER $user $host $server :[$this getIrcname]
     $this qSend NICK $ndata(nickname)
-    if !$ndata(noRefresh) { $this channelList { } }
-    retitleFrame .@inf [$this info] [set msg "[$this name] - [$this host]"] 1
-    retitleFrame .@ctl $this $msg 1
+    if {!$ndata(noRefresh)} { $this channelList { } }
+    retitleFrame [MainInfo] [$this info] [set msg "[$this name] - [$this host]"] 1
+    retitleFrame [MainControl] $this $msg 1
     $this configure -startup 1
-    if $DEBUG { zDBGRet $this }
+    if {$DEBUG} { zDBGRet $this }
     return 1
 }
 #
@@ -355,8 +386,8 @@ proc net_changeServer {this srv args} {
 	[$this control] showServer [$this hostid]
 	return
     }
-    if [$this active] {
-	$this inform "Closing connection to [$this host]"
+    if {[$this active]} {
+	set host [$this host]
 	$this closeSock {Changing Servers}
 	$this flagControl disabled
 	foreach x {channels messages notices} {
@@ -364,295 +395,16 @@ proc net_changeServer {this srv args} {
 	}
 	$this irc305
 	set zircon(j) 0
-	$this inform "About to connect to [$srv host]"
-	after 3000
+	switch {} [$this closing] {} default {
+	    $this inform "Waiting for $host to close."
+	    uplevel #0 vwait ${this}(closing)
+	}
     }
     $this startIRC $srv
 }
 #
-proc showFull {net w x y yl} {
-    upvar #0 $net ndata
-    set chan [lindex $ndata(allChannels) [$w nearest $yl]]
-    set w [toplevel .@lt$net -class Zircon]
-    wm overrideredirect $w 1
-    wm geometry $w +$x+$y
-    grid [label $w.l -text $chan -bg yellow] -ipadx 3 -ipady 3
-}
-#
-proc listClear {net w} {
-    global $net
-    $w.chn.l delete 0 end
-    set ${net}(allChannels) {}
-    catch {destroy .lt$net}
-}
-#
-proc net_channelList {this doit} {
-    global showList
-    upvar #0 $this ndata
-    set ndata(allChannels) {}
-    set w .@l$this
-    if ![winfo exists $w] {
-	toplevel $w -class Zircon
-	wm title $w "[$this name] Channel List"
-	wm iconname $w "[$this name] Channel List"
-	frame $w.filter -relief raised
-	checkbutton $w.filter.public -variable ${this}(showPublic) \
-	  -text [trans public]
-	checkbutton $w.filter.local -variable ${this}(showLocal) \
-	  -text [trans local]
-	checkbutton $w.filter.private -variable ${this}(showPrivate) \
-	  -text [trans private]
-	checkbutton $w.filter.topic -variable ${this}(topicOnly) \
-	  -text [trans {With Topic}]
-	checkbutton $w.filter.sorted -variable ${this}(sorted) \
-	  -text [trans sorted]
-	checkbutton $w.filter.nocase -variable ${this}(nocase) -text {Ignore Case}
-
-	scale $w.filter.minm \
-	  -from 1 -to 25 -label {Minimum Number of Members} \
-	  -showvalue 1 -orient horizontal \
-	  -command "set ${this}(minMembers)"
-
-	$w.filter.minm set $ndata(minMembers)
-
-	grid $w.filter.minm - - -sticky ew
-	scale $w.filter.maxm \
-	  -from 0 -to  50 -label {Maximum Number of Members} \
-	  -showvalue 1 -orient horizontal \
-	  -command "set ${this}(maxMembers)"
-	$w.filter.maxm set $ndata(maxMembers)
-
-	grid $w.filter.maxm - - -sticky ew
-	grid $w.filter.public $w.filter.local $w.filter.private -sticky w
-	grid $w.filter.topic $w.filter.sorted $w.filter.nocase -sticky w
-	labelEntry 0 $w.filter2 {-text Channel} [$this listPattern] {}
-	labelEntry 0 $w.filter3 {-text Topic} [$this topicPattern] {}
-	$w.filter2.entry configure -textvariable ${this}(listPattern)
-	$w.filter3.entry configure -textvariable ${this}(topicPattern)
-	makeLB $w.chn -width 20 -height 8
-	frame $w.btn
-	evenGrid $w.btn column 0 2
-	button $w.btn.ok -text [trans dismiss] -relief raised \
-	  -command "destroy $w ; catch {destroy .@lt$this}"
-	button $w.btn.clear -text [trans clear] -relief raised \
-	  -command "listClear $this $w"
-	button $w.btn.list -text [trans list] -relief raised \
-	  -command "listBC $w $this {}"
-	grid $w.btn.list $w.btn.clear $w.btn.ok -sticky ew
-	grid columnconfigure $w 0 -weight 1
-	grid rowconfigure $w 3 -weight 1
-	grid $w.filter -sticky ew
-	grid $w.filter2 -sticky ew
-	grid $w.filter3 -sticky ew
-	grid $w.chn -sticky nsew
-	grid $w.btn -sticky ew
-	bind $w.chn.l <Double-Button-1> "
-	    notIdle $w $this
-	    channelJoin $this \[lindex \$${this}(allChannels) \[%W nearest %y\]\] {}
-	    break
-	"
-	bind $w.chn.l <ButtonPress-2> "
-	    notIdle %W $this
-	    showFull $this %W %X %Y %y
-	    break
-	"
-	bind $w.chn.l <ButtonRelease-2> "notIdle %W $this ; catch {destroy .@lt$this}; break"
-	bind $w.chn.l <Button-1> "
-	    notIdle $w $this
-	    [$this control] configure -channel \[lindex \$${this}(allChannels) \[%W nearest %y\]\]
-	    break
-	"
-    } {
-	popup $w
-	switch {} $doit {} default {$w.chn.l delete 0 end}
-    }
-    set showList 0
-    switch {} $doit {} default {
-	listBC $w $this $doit
-	set showList 1
-    }
-}
-#
-proc listBC {w net chan} {
-    upvar #0 $net ndata
-    $w.chn.l delete 0 end
-    catch {grab set $w}
-    $w configure -cursor watch
-    $w.btn.list configure -state disabled
-    switch {} ndata(listPattern) {
-	set ndata(listPattern) .*
-    } default {
-	if {[catch {regexp $ndata(listPattern) test} msg]} {
-	    set ndata(listPattern) .*
-	    tellError {} Error "Bad regexp for list pattern:\n$msg"
-	}
-    }
-    switch {} $ndata(topicPattern) {
-	set ndata(topicPattern) .*
-    } default {
-	if {[catch {regexp $ndata(topicPattern) test} msg]} {
-	    set ndata(topicPattern) .*
-	    tellError {} Error "Bad regexp for topic pattern:\n$msg"
-	}
-    }
-    foreach x {filter2.entry filter3.entry filter.public filter.local
-      filter.topic filter.sorted filter.nocase filter.private
-      filter.maxm filter.minm} {
-	$w.$x configure -state disabled
-    }
-    set ndata(allChannels) {}
-    set pbdy "global showList
-    upvar #0 $net ndata
-    "
-    append pbdy {regsub -all "\t" $pargs "\\\t" pargs
-    set chan [lindex $pargs 1]
-    }
-    append pbdy "set w .@l$net
-    "
-    append pbdy {set memb [lindex $pargs 2]
-    }
-    append pbdy "if !\$showList \{switch -glob -- \$chan {\\*} "
-    if $ndata(showPrivate) {
-	append pbdy {{set chan Prv}}
-    } {
-	append pbdy return
-    }
-    if !$ndata(showLocal) {append pbdy { &* return}}
-    if !$ndata(showPublic) {append pbdy { {[#+]*} return}}
-    if $ndata(topicOnly) {append pbdy { ; switch {} $param return}}
-    if {$ndata(minMembers) > 1 || $ndata(maxMembers) > 0} {
-	if {$ndata(minMembers) > 1} {
-	    append pbdy { ; if {$memb < $ndata(minMembers)} return}
-	}
-	if {$ndata(maxMembers) > 0} {
-	    append pbdy { ; if {$memb > $ndata(maxMembers)} return}
-	}
-    }
-    switch .* $ndata(listPattern) {} default {
-	append pbdy { ; if ![regexp -nocase $ndata(listPattern) $chan] return}
-    }
-    switch .* $ndata(topicPattern) {} default {
-	append pbdy { ; if ![regexp -nocase $ndata(topicPattern) $param] return}
-    }
-    append pbdy " \} ; $net configure +allChannels \$chan"
-    append pbdy {
-    if ![catch {set lln \
-	"[format {%-12s %3d %s} [string range $chan 0 11] $memb $param]"}] {
-	  $w.chn.l insert end $lln
-    }
-    }
-    proc doChkList$net {pargs param} $pbdy
-    if [$net undernet] { underList $net $chan } {
-	switch {} $chan {$net q1Send LIST} default {$net qSend LIST :$chan}
-    }
-}
-#
-proc net_irc321 {this args} {
-    if ![winfo exists .@l$this] return
-    upvar #0 ${this}(listFile) lf
-    if [catch {open [file join [tmpdir] list[pid]] w+} lf] {
-	set lf {}
-    }
-}
-#
-proc net_irc322 {this prefix param pargs} {
-    if ![winfo exists .@l$this] return
-    upvar #0 ${this}(listFile) lf
-    switch {} $lf {doChkList$this $pargs $param} default {
-	puts $lf $pargs
-	puts $lf $param
-    }
-}
-#
-proc net_listline {this pargs param} {
-    global showList
-    upvar #0 $this ndata
-    regsub -all "\t" $pargs "\\\t" pargs
-    set chan [lindex $pargs 1]
-    set w .@l$this
-    if !$showList {
-	switch -glob -- $chan {
-	{\*}  {if !$ndata(showPrivate) return {set chan Prv }}
-	&*  {if !$ndata(showLocal) return}
-	{[#+]*} {if !$ndata(showPublic) return}
-	}
-    }
-    set memb [lindex $pargs 2]
-    set max 1000000
-    if {$ndata(maxMembers) > 0} { set max $ndata(maxMembers) }
-    if !$showList {
-	switch {} $param { if $ndata(topicOnly) return }
-	if {$memb < $ndata(minMembers) || $memb > $max} return
-	if ![regexp -nocase $ndata(listPattern) $chan] return
-	if ![regexp $ndata(topicPattern) $param] return
-    }
-    $this configure +allChannels $chan
-    if ![catch {set lln \
-	"[format {%-12s %3d %s} [string range $chan 0 11] $memb $param]"}] {
-	  $w.chn.l insert end $lln
-    }
-}
-#
-proc net_irc323 {this prefix param pargs} {
-    global showList
-    upvar #0 ${this}(listPattern) listPattern \
-      ${this}(topicPattern) topicPattern $this ndata
-    set showList 0
-    set w .@l$this
-    catch {grab release $w}
-    catch {$w configure -cursor arrow}
-    switch {} [set fd $ndata(listFile)] {} default {
-	update
-	if [winfo exists $w] {
-	    seek $fd 0 start
-	    set lcount -50
-	    if $ndata(sorted) {
-		while {![eof $fd]} {
-		    lappend lst [list [gets $fd] [gets $fd]]
-		    if ![incr lcount] {
-			update
-			if ![winfo exists $w] break
-			set lcount -50
-		    }
-		}
-		set lcount -50
-		foreach x [if $ndata(nocase) {lsort -command noCase $lst} \
-		  {lsort $lst}] {
-		    doChkList$this [lindex $x 0] [lindex $x 1]
-		    if ![incr lcount] {
-			update
-			if ![winfo exists $w] break
-			set lcount -50
-		    }
-		}
-	    } {
-		while {![eof $fd]} {
-		    doChkList$this [gets $fd] [gets $fd]
-		    if ![incr lcount] {
-			update
-			if ![winfo exists $w] break
-			set lcount -50
-		    }
-		}
-	    }
-	}
-	catch {filedelete [file join [tmpdir] list[pid]] }
-	close $fd
-	set ndata(listFile) {}
-    }
-    foreach x {filter2.entry filter3.entry filter.public filter.local
-      filter.topic filter.sorted filter.nocase filter.private
-      filter.maxm filter.minm btn.list} {
-	catch {$w.$x configure -state normal}
-    }
-}
-#
-proc noCase {t1 t2} {
-    return [string compare [string tolower $t1] [string tolower $t2]]
-}
-#
 proc net_deIRCOp {this} {
-    if [$this gircop] { set md -o } { set md -O }
+    if {[$this gircop]} { set md -o } { set md -O }
     $this MODE [$this nickname] $md
 }
 #
@@ -673,7 +425,7 @@ proc net_setNickname {this nk} {
 }
 #
 proc net_changeNickname {this nk} {
-    if [$this active] {
+    if {[$this active]} {
 	$this NICK $nk
 	$this configure -nickwait 1
     } { $this setNickname $nk }
@@ -681,14 +433,14 @@ proc net_changeNickname {this nk} {
 #
 proc net_changeIRCName {this name} {
     $this configure -ircname $name
-    if [$this active] {
-	tellInfo Warning {Change will not take effect until next server change.}
+    if {[$this active]} {
+	tellInfo $this Warning {Change will not take effect until next server change.}
     }
 }
 #
 proc net_irc305 {this} {
     upvar #0 $this ndata
-    if !$ndata(busy) {[$this control] blackit away}
+    if {!$ndata(busy)} {[$this control] blackit away}
     set ndata(away) 0
 }
 #
@@ -713,7 +465,7 @@ proc net_close {this args} {
 	set port [$srv port]
     }
     switch [llength $args] {
-    2 {set msg {} ; set qmsg [lindex $args 0] ; set recon 0}
+    2 {set msg {} ; switch {} [set qmsg [lindex $args 0]] { set qmsg { }}; set recon 0}
     1 { set msg [lindex $args 0] }
     0 { set msg "Server $host has closed the connection." }
     }
@@ -727,9 +479,9 @@ proc net_close {this args} {
     $this irc305
     set zircon(j) 0
     handleOn $this CLOSE [list $host $port]
-    if $recon {
+    if {$recon} {
 	bell
-	if [$this reconnect] {startReconn $this $srv $msg} \
+	if {[$this reconnect]} {startReconn $this $srv $msg} \
 	elseif {[$this srvcycle]} {
 	    set s $ndata(servers)
 	    set pos [lsearch $s $srv]
@@ -737,7 +489,8 @@ proc net_close {this args} {
 	    switch {} [set srv [lindex $s $pos]] {set srv [lindex $s 0]}
 	    after 0 $this doReconnect $srv
 	} {
-	    if [askUser SHUT [trans shutdown] "$msg\nReconnect?"] {
+	    if {[listmember [$this alwayslog] CLOSE]} {$this inform $msg}
+	    if {[askUser SHUT [trans shutdown] "$msg\nReconnect?"]} {
 		after 0 $this doReconnect $srv
 	    }
 	}
@@ -746,7 +499,7 @@ proc net_close {this args} {
 #
 proc startReconn {net srv msg} {
     upvar #0 $net ndata
-    if ![winfo exists .@cl$net] {
+    if {![winfo exists .@cl$net]} {
 	mkDialog {} .@cl$net [trans shutdown] \
 	  "$msg - [trans reconnecting]." {} \
 	  "{Stop trying} {stopReconn $net}"
@@ -754,10 +507,12 @@ proc startReconn {net srv msg} {
     set ndata(reconaft) [after 5000 $net doReconnect $srv]
 }
 #
-proc stopReconn {net} {
-    upvar #0 $net ndata
-    catch {after cancel $ndata(reconaft)}
-    catch {unset $ndata(reconaft)}
+proc stopReconn {this} {
+    upvar #0 $this ndata
+    if [info exists $ndata(reconaft)] {
+        catch {after cancel $ndata(reconaft)}
+        unset ndata(reconaft)
+    }
 }
 #
 proc net_doReconnect {this srv} {
@@ -766,19 +521,17 @@ proc net_doReconnect {this srv} {
     }
 }
 #
-proc net_deMonitor {this chan} {
+proc net_deMonitor {this chid} {
     upvar #0 $this ndata
-    listkill ndata(monitorlst) $chan
+    listkill ndata(monitorlst) [$chid lname]
     switch {} $ndata(monitorlst) {after cancel "$this monitorTest"}
 }
 #
-proc net_monitor {this chan} {
-    switch {} $chan return
-    if ![[set chid [Channel :: make $this $chan]] active] {
+proc net_monitor {this chid} {
+    if {![$chid active]} {
 	upvar #0 $this ndata
-	set chan [$chid lname]
-	listincl ndata(monitorlst) $chan
-	$chid configure -monitor 1
+	listincl ndata(monitorlst) [$chid lname]
+	$chid monitorOn
 	$this monitorTest
     }
 }
@@ -795,7 +548,7 @@ proc net_clearTest {this} {
     foreach x {messages notices} {
 	foreach chn [$this $x] {
 	    foreach usr [$chn users] {
-		if ![$this me $usr] {
+		if {![$this me $usr]} {
 		    append lst " [$usr name]"
 		    lappend mc $usr
 		}
@@ -813,21 +566,20 @@ proc net_setupTests {this} {
     upvar #0 $this ndata
     $this ISON
     upvar #0 $this ndata
-    if $ndata(ping) {
+    if {$ndata(ping)} {
 	set ndata(pinged) 0
 	after $ndata(ping) "$this pingTest"
     }
     $this monitorTest
-    if $ndata(notifyInterval) {after $ndata(notifyInterval) "$this isonTest"}
+    if {$ndata(notifyInterval)} {after $ndata(notifyInterval) "$this isonTest"}
     after $ndata(testTime) "$this ircTests"
-    if $ndata(cleargone) {
+    if {$ndata(cleargone)} {
 	after 600000 "$this clearTest"
     }
 }
 #
 proc net_ircTests {this} {
-    upvar #0 MkOp$this MkOp
-    upvar #0 $this ndata
+    upvar #0 MkOp$this MkOp $this ndata
     incr ndata(idle) [expr {$ndata(testTime) / 1000}]
     if {!$ndata(away) && $ndata(autoAway) && $ndata(idle) > $ndata(autoAway)} {
 	$this AWAY {is away}
@@ -837,7 +589,7 @@ proc net_ircTests {this} {
 	    set flag +
 	    set ind -1
 	    foreach n $MkOp($id) {
-		if ![$id isOp $n] {
+		if {![$id isOp $n]} {
 		    incr ind
 		    append flag o
 		    switch +ooo $flag {
@@ -865,13 +617,13 @@ proc net_ircTests {this} {
 proc net_isonTest {this} {
     upvar #0 $this ndata
     $this ISON
-    if $ndata(notifyInterval) {after $ndata(notifyInterval) "$this isonTest"}
+    if {$ndata(notifyInterval)} {after $ndata(notifyInterval) "$this isonTest"}
 }
 #
 proc net_pingTest {this} {
     upvar #0 $this ndata
     set nm [$this host]
-    if $ndata(pinged) {
+    if {$ndata(pinged)} {
 	$this close "Server $nm is not responding - closing the connection"
     } {
 	$this PING $nm
@@ -895,27 +647,16 @@ proc net_newSplit {this split} {
 proc net_cleanSplit {this h} {
     global Split Heal TSplit
     upvar #0 $this ndata
-    if [info exists Split($h)] {
+    if {[info exists Split($h)]} {
 	set frnd [$this finfo]
 	foreach user $Split($h) {
-	    if [catch {set nk [$user name]}] continue
+	    if {[catch {set nk [$user name]}]} continue
 	    foreach x {Chat Message Notice} {
 		switch nil [set msg [$x :: find $nk $this]] {} default {
-		    if [$msg active] {
-			$msg flag normal
-			$msg addText {} \
-			  "*** netsplit : $nk may have left IRC."
-		    }
-		}
-	    }
-	    foreach id [$this channels] {
-		if {[$id isJoined $user] &&
-		  ![normal [$id window].uFrm.userBtn.$user]} {
-		    $id killUser $user
-		} elseif {[$id monitor]} {
-		    catch {destroy .@mon$id.users.userList.$user}
+		    $msg heal
 		}
 	    }
+	    foreach id [$this channels] { $id remove $user }
 	    $frnd remove [$user fobj]
 	    $user deref
 	}
@@ -948,14 +689,17 @@ proc net_INFO {this args} {
 }
 #
 proc net_ISON {this} {
-    if ![$this active] return
+    if {![$this active]} return
     set ns {}
-    foreach x [$this friends] {	if [$x notify] { append ns " [$x name]"}}
+    foreach x [$this friends] {	if {[$x notify]} { append ns " [$x name]"}}
     switch {} $ns return
     $this sysQ "ISON :$ns"
 }
 #
-proc net_SQUIT {this srv} { $this qSend SQUIT :$srv }
+proc net_SQUIT {this srv reason} { 
+    switch {} $reason { set reason {No reason given} }
+    $this qSend SQUIT $srv :$reason
+}
 #
 proc net_TIME {this nk} { $this qSend TIME :$nk }
 #
@@ -984,9 +728,7 @@ proc net_STATS {this p1 p2} { $this qSend STATS $p1 :$p2 }
 proc net_USERHOST {this nk} { $this qSend USERHOST :$nk }
 #
 proc net_NICK {this name} {
-    if [$this startup] {
-	$this setNickname $name
-    }
+    if {[$this startup]} { $this setNickname $name }
     $this qSend NICK :$name
 }
 proc net_MODE {this who mode args} {
@@ -1045,7 +787,7 @@ proc net_PING {this srv} { $this qSend PING :$srv}
 #
 proc net_error {this prefix param pargs} {
     set hst [$this host]
-    if [$this startup] {
+    if {[$this startup]} {
 	set msg "Cannot connect to $hst : $param"
     } {
 	set msg "Closing connection to $hst, ERROR : $param"
@@ -1070,11 +812,12 @@ proc net_delete {this} {
 	foreach y [$this $x] { $y delete }
     }
     foreach x [$this users] { $x configure -ref 0 ; $x delete }
-    deleteFrame .@ctl $this
-    deleteFrame .@inf [$this info]
+    [$this control] delete
+    [$this info] delete
+    [$this listid] delete
     catch {deleteFrame .@dbgctl $this}
-    global XTO OType $this znetList
-    unset XTO([string tolower [$this name]]) OType($this) $this
+    global znetList
+    safeUnset [list XTO([string tolower [$this name]])] OType($this) $this
     listkill znetList $this
 }
 #
@@ -1102,4 +845,33 @@ proc net_SERVLIST {this n t} {
     switch {} $t return
     $this qSend SERVLIST "$n :$t"
 }
-
+#
+proc net_clearMsgs {this usrs} {
+    switch {} [set mc [$this msgclear]] {} default {
+	foreach frd $usrs { listkill mc $frd }
+	foreach frd $mc {
+	    set nm [$frd name]
+	    foreach x {Message Notice} {
+		switch nil [set chn [$x :: find $nm $net]] continue
+		$chn doLeave {}
+	    }
+	}
+	$this configure -msgclear $mc
+    }
+}
+#
+proc net_fileProcess {this file usr} {
+    foreach x [$this helpers] {
+        if {[regexp [lindex $x 0] $file]} {
+	    set cmd [lindex $x 1]
+	    set np [lindex $x 2]
+	    if {[regexp -nocase $np [$usr name]]} {
+	        regsub -all %s $cmd $file cmd
+	        if {[catch {eval exec $cmd &} msg]} {
+	    	    tellError {} Error "Error executing helper cmd $cmd - $msg"
+	        }
+		return
+	    }
+	}
+    }
+}
