@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Notrace.tcl,v $
-# $Date: 1997/07/18 08:01:31 $
-# $Revision: 1.18.1.12 $
+# $Date: 1998/02/24 11:52:53 $
+# $Revision: 1.18.1.24 $
 #
 #
 package provide Notrace 1.18
@@ -9,7 +9,7 @@ package provide Notrace 1.18
 proc ircInput {mode conn} {
     global STN zircon inexp1 inexp2 currentNet
     set net $STN($conn)
-    if [catch {gets $conn} line] {
+    if {[catch {gets $conn} line]} {
 	switch {socket is not connected} $line {
 	    set line {connection request timed out}
  	}
@@ -17,9 +17,12 @@ proc ircInput {mode conn} {
 	return
     }
     
-    if [eof $conn] { $net close } {
-	if ![regexp $inexp1 $line match prefix cmd b c d e param] {
-	    if ![regexp $inexp2 $line match prefix cmd b] {
+    if {[eof $conn]} {
+	$net doClose $conn
+	switch $conn [$net sock] { $net close }
+    } {
+	if {![regexp $inexp1 $line match prefix cmd b c d e param]} {
+	    if {![regexp $inexp2 $line match prefix cmd b]} {
 		switch {} $line {} default {
 		    $net errmsg "Error on server connection - $line"
 		}
@@ -35,50 +38,71 @@ proc ircInput {mode conn} {
 		return
 	    }
 	ERROR {
-		$net error {} [string range $line 7 end] {}
+		switch {} [$net closing] {
+		    $net error {} [string range $line 7 end] {}
+		} default {
+		    $net doClose $conn
+		}
 		return
 	    }
+	NOTICE {
+		set prefix :[$net host]
+		set b $cmd
+		set cmd NOTICE
+	    }
 	default { set prefix :[$net host] }
 	}
-	set pargs [safeClean [string range $b 1 end]]
-	if [catch {irc$cmd $net $prefix $param $pargs} msg] {
+	if {[catch {irc$cmd $net $prefix $param [safeClean [string range $b 1 end]]} msg]} {
 	    zError $msg $cmd $prefix $param [string range $b 1 end]
 	}
     }
 }
 #
-proc connect {host port} {
-    set sk [socket $host $port]
-    sconf $sk
-    return $sk
-}
-#
 proc net_send {this op args} {
     upvar #0 $this ndata
     switch {} $ndata(sock) return
     set msg $op
-     switch : [set last :[lindex $args end]] {} default {
-	if ![catch {set foo [lreplace $args end end]}] {
+    switch : [set last :[lindex $args end]] {} default {
+	if {![catch {set foo [lreplace $args end end]}]} {
 	    append msg " $foo $last"
 	}
     }
-    if [catch {puts $ndata(sock) $msg}] {$this close}
+    if {[catch {puts $ndata(sock) $msg} err]} {$this close $err}
 }
 #
 proc net_qSend {this op args} {
     upvar #0 $this ndata
-    if [catch {puts $ndata(sock) "$op [join $args]"} msg] {$this close $msg}
-}
-#
-proc net_q1Send {this op} {
-    upvar #0 $this ndata
-    if [catch {puts $ndata(sock) $op} msg] { $this close $msg }
+    if {[catch {puts $ndata(sock) "$op [join $args]"} msg]} {$this close $msg}
 }
 #
 proc net_sendRaw {this value} {
     upvar #0 ${this}(sock) sock
     switch {} $sock return
-    if [catch {puts $sock $value} msg] {$this close $msg}
+    if {[catch {puts $sock $value} msg]} {$this close $msg}
+}
+#
+proc net_q1Send {this op} {
+    upvar #0 $this ndata
+    if {[catch {puts $ndata(sock) $op} msg]} { $this close $msg }
+}
+#
+proc connect {host port} {
+    set sk [socket $host $port]
+    sconf $sk {}
+    return $sk
+}
+#
+proc net_doClose {this sock} {
+    switch {} $sock return
+    upvar #0 $this ndata
+    catch {close $sock}
+    switch $sock $ndata(sock) {
+	$this inform "Connection to [$this host] closed"
+    }
+    switch {} $ndata(closing) {} default {
+	catch {after cancel $ndata(closing)}
+	set ndata(closing) {}
+    }
 }
 #
 proc net_closeSock {this msg} {
@@ -92,21 +116,21 @@ proc net_closeSock {this msg} {
     switch {} [set sock $ndata(sock)] {} default {
 	set ndata(sock) {}
 	set ndata(pinged) 0
-	switch {} $msg {} default {catch {puts $sock "QUIT :$msg"}}
-	catch {close $sock}
-	$this inform "Connection to [$this host] closed"
-    }
-    retitleFrame .@inf [$this info] [$this name] 1
-    retitleFrame .@ctl $this [$this name] 1
-    if [winfo exists .@l$this] {
-	catch {grab release .@l$this}
-	catch {.@l$this configure -cursor arrow}
+	switch {} $msg {
+	    $this doClose $sock
+	} default {
+	    catch {puts $sock "QUIT :$msg"}
+	    set ndata(closing) [after $ndata(quitwait) "$this doClose $sock"]
+	}
     }
+    retitleFrame [MainInfo] [$this info] [$this name] 1
+    retitleFrame [MainControl] $this [$this name] 1
+    [$this listid] release
 }
 #
 proc net_queue {this req} {
     upvar #0 $this ndata
-    if $ndata(antiflood) {
+    if {$ndata(antiflood)} {
 	switch {} $ndata(maxQueue) {} default {
 	    if {$ndata(msgQLen) >= $ndata(maxQueue)} return
 	}
@@ -123,15 +147,15 @@ proc net_popQueue {this} {
     set ndata(msgQTag) {}
     switch {} $ndata(sysQueue) {
 	switch {} $ndata(msgQueue) return
-	if [catch {puts $ndata(sock) [lindex $ndata(msgQueue) 0]} msg] {
+	if {[catch {puts $ndata(sock) [lindex $ndata(msgQueue) 0]} msg]} {
 	    $this close $msg
 	}
 	set ndata(msgQueue) [lrange $ndata(msgQueue) 1 end]
-	if [incr ndata(msgQLen) -1] {
+	if {[incr ndata(msgQLen) -1]} {
 	    set ndata(msgQTag) [after $ndata(antiflood) "$this popQueue"]
 	}
     } default {
-	if [catch {puts $ndata(sock) [lindex $ndata(sysQueue) 0]} msg] {
+	if {[catch {puts $ndata(sock) [lindex $ndata(sysQueue) 0]} msg]} {
 	    $this close $msg
 	}
 	switch {} [set ndata(sysQueue) [lrange $ndata(sysQueue) 1 end]] { 
@@ -145,13 +169,13 @@ proc net_popQueue {this} {
 }
 #
 proc chat_action {this string} {
-    notIdle {}
+    notIdle {} [$this net]
     switch {} $string return
     upvar #0 ${this}(sock) sock
     switch {} $sock {
 	$this addText {} {*** Connection is closed!!!!}
     } default {
-	if [catch {puts $sock "\001ACTION $string\001"} err] {
+	if {[catch {puts $sock "\001ACTION $string\001"} err]} {
 	    $this addText {} "*** Error : $err"
 	} {
 	    set net [$this net]
@@ -162,17 +186,19 @@ proc chat_action {this string} {
 }
 #
 proc chat_send {this string args} {
-    notIdle {}
+    notIdle {} [set net [$this net]]
     switch {} $string return
     upvar #0 ${this}(sock) sock
+    $this addHist $string
     switch {} $sock {
 	$this addText {} {*** Connection is closed!!!!}
     } default {
-	if [catch {puts $sock $string} err] {
+	if {[catch {puts $sock $string} err]} {
 	    $this addText {} "*** Error : $err"
 	} {
 	    flush $sock
-	    $this addText @me "= $string"
+	    regsub -all %n [$this mytag] [[$net myid] name] pr
+	    $this addText @me "$pr $string"
 	}
     }
 }
@@ -180,7 +206,7 @@ proc chat_send {this string args} {
 proc acceptChat {usr newc hst args} {
     set net [$usr net]
     upvar #0 AChat$net AChat
-    [set cht [Chat [$usr name] -caller $usr]] show
+    [set cht [$net eval "Chat [list [$usr name]] -caller $usr"]] show
     $cht addUser $usr 0 0
     upvar #0 $newc chdata
     $cht configure -sock $newc
@@ -191,6 +217,5 @@ proc acceptChat {usr newc hst args} {
     fileevent $newc readable "dccChat r $newc"
     catch {close $AChat($usr)}
     catch {unset AChat($usr)}
-    $usr deref
-    if [winfo exists .@dls$net] { buildDCCList $net }
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
