@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confChan.tcl,v $
-# $Date: 1997/06/07 13:14:29 $
-# $Revision: 1.18.1.18 $
+# $Date: 1998/02/09 16:57:01 $
+# $Revision: 1.18.1.25 $
 #
 package provide zircon 1.18
 #
@@ -11,7 +11,7 @@ proc editChan {net pos win chan} {
     switch {} $chan return
     switch -- [set lchan [string tolower $chan]] [$selID($net) lname] return
     $win delete $pos
-    confInsSel $win $pos $chan
+    confInsSel $win $pos [list $chan]
     set news(name) $chan
     set news(lname) $lchan
 }
@@ -19,14 +19,15 @@ proc editChan {net pos win chan} {
 proc selectDefault {net} {
     global defChan selID
     set selID($net) $defChan($net)
-    setCCB $net *DEFAULT*
+    setCCB $net $defChan($net)
 }
 #
 proc changeChan {net dbl win y} {
-    global selID defChan
+    global selID defChan lbdata
     saveChan $net
-    switch *NEW* [set cnm [$win get [set p [$win nearest $y]]]] {
-	if $dbl {
+    set v [lindex $lbdata($win) [set p [$win nearest $y]]]
+    switch {} [set chn [lindex $v 1]] {
+	if {$dbl} {
 	    set selID($net) nil
 	    setCCB $net {}
 	    confAddChan $net $win $p
@@ -36,57 +37,54 @@ proc changeChan {net dbl win y} {
 	    selectDefault $net
 	}
     } default {
-	set selID($net) [Channel :: find $cnm $net]
-	setCCB $net $cnm
+	set selID($net) $chn
+	set cnm [lindex $v 0]
+	setCCB $net $chn
 	confSelClear $win $p
 	if {$dbl && [string compare $selID($net) $defChan($net)]} {
-	    confDABtns $net .@cfChannels$net
+	    confDABtns $net
 	    tkwait window [mkEntryBox {} {Edit Channel} \
 	      {Edit the channel name:} [list [list channel $cnm]] \
 	      [list ok "editChan $net $p $win"] \
 	      [list delete "confDelChan $net $win $y"] \
 	      [list cancel {}]]
-	    confRABtns $net .@cfChannels$net
+	    confRABtns $net
 	}
     }
 }
 #
 proc setCCB {net chan args} {
-    global confData confB Configure.Channel
-    set w .@cfChannels$net.chan
+    global confB Configure.Channel
+    set w .@conf$net.f.chld
     switch {} $chan {
 	foreach wc [winfo children $w.options] {
 	    switch $wc $w.options.msg {} default {$wc conf -state disabled}
 	}
-	foreach i {history closetime icon1 icon2 logfile key} {
-	   $w.values.$i.entry conf -state disabled
-	}
-	foreach i {fg bg} { $w.values.$i conf -state disabled }
+	foreach i [winfo children $w.values] {$i.entry conf -state disabled}
+	foreach i [winfo children $w.look] {$i conf -state disabled}
 	return
     }
     foreach i [winfo children $w.options] {
 	switch $i $w.options.msg {} default {$i conf -state normal}
     }
     foreach i [winfo children $w.values] {catch {$i.entry conf -state normal}}
-    foreach i {fg bg} { $w.values.$i conf -state normal }
-    set chan [Channel :: find $chan $net]
+    foreach i [winfo children $w.look] {catch {$i conf -state normal}}
     upvar #0 new$chan new
-    foreach v $confData(channel) {
-	set tn [lindex $v 1]
-	$w.options.$tn configure -variable new${chan}($tn)
-    }
     foreach b [lindex [set Configure.Channel(msg)] 1] {
 	set b [string toupper $b]
 	set lb [string tolower $b]
 	set confB($lb) [expr {[lsearch $new(msg) $b] < 0}]
     }
-    entrySet $w.values.history.entry [$chan history]
-    entrySet $w.values.closetime.entry [$chan closetime]
+    foreach x [array names Configure.Channel] {
+	switch [lindex [set Configure.Channel($x)] 0] bool {
+	    $w.options.$x configure -variable new${chan}($x)
+	} int - file - key {
+	    entrySet $w.values.$x.entry [$chan $x]
+	}
+    }
     set v $new(icon)
     entrySet $w.values.icon1.entry [lindex $v 0]
     entrySet $w.values.icon2.entry [lindex $v 1]
-    entrySet $w.values.logfile.entry [$chan logfile]
-    entrySet $w.values.key.entry [$chan key]
 }
 #
 proc CancelCAC {net win posn args} {
@@ -95,30 +93,31 @@ proc CancelCAC {net win posn args} {
 }
 #
 proc doCAC {net win posn chan} {
+    global lbdata
     switch -glob -- $chan {} return {[&#+]*} {} default {set chan #$chan}
     set chid [Channel :: make $net $chan]
     upvar #0 new$chid newc
     set x $posn
-    if ![array exists newc] { $chid pack new }
-    if ![$chid keep] {
-	set x [expr {[$win size] - 2}]
-	$win insert $x $chan
+    if {![array exists newc]} { $chid pack new }
+    if {![$chid keep]} {
+	set x [expr {[llength $lbdata($win)] - 2}]
+	set lbdata($win) [linsert $lbdata($win) $x [list $chan $chid]]
 	$chid configure -keep 1 -sys 0
     }
     uplevel #0 "set selID($net) $chid ; lappend newChn($net) $chid"
     set newc(keep) 1
     set newc(sys) 0
     confSelClear $win $x
-    setCCB $net $chan
-    confDirty $net [winfo toplevel $win]
+    setCCB $net $chid
+    confDirty $net
 }
 #
 proc confAddChan {net win posn} {
-    confDABtns $net .@cfChannels$net
+    confDABtns $net
     tkwait window [mkEntryBox {} {New Channel} {Enter the channel name:} \
       [list [list channel {}]] [list ok "doCAC $net $win $posn"] \
       [list cancel "CancelCAC $net $win $posn"]]
-    confRABtns $net .@cfChannels$net
+    confRABtns $net
 }
 #
 proc confDelChan {net win y args} {
@@ -130,7 +129,7 @@ proc confDelChan {net win y args} {
 	$selID($net) configure -keep 0
 	if {[set x [lsearch $newChn($net) $selID($net)]] >= 0} {
 	    listdel newChn($net) $x
-	    if ![$selID($net) active] {
+	    if {![$selID($net) active]} {
 		$selID($net) configure -keep 0
 		$selID($net) delete
 	    }
@@ -139,87 +138,82 @@ proc confDelChan {net win y args} {
 	}
 	set cnm [string tolower [$win get $dx]]
 	confSelClear $win $dx
-	set selID($net) [Channel :: find $cnm $net]
-	setCCB $net $cnm
+	setCCB $net [set selID($net) [Channel :: find $cnm $net]]
     }
-    confDirty $net [winfo toplevel $win]
+    confDirty $net
 }
 #
-proc confChannels {net} {
-    set win .@cfChannels$net
-    if [winfo exists $win] { popup $win ; return }
+proc confChannels {net win} {
+    global defChan selID Configure.Channel lbdata
     confInit $net Channels
-    toplevel $win -class Zircon
-    wm title $win "[$net name] - Channel Configuration"
-    wm iconname $win Channels
-    wm protocol $win WM_DELETE_WINDOW "confDismiss $net Channels"
-    set winc [frame $win.chan -relief raised]
-    set wincn [frame $winc.nels]
-    grid columnconfigure $wincn 0 -weight 1
-    grid rowconfigure $wincn 0 -weight 1
-    label $wincn.label -text Channels
-    makeLB $wincn.list
-    global confData defChan selID Configure.Channel
+    set wincn [makeLB $win.nels]
+    set lbdata($wincn.l) {}
+    trace variable lbdata($wincn.l) w lbUpdate
+    set ld {}
     foreach c [$net channels] {
 	if {[string compare $c $defChan($net)] && ![$c sys] && [$c keep]} {
-	    $wincn.list.l insert end [$c name]
+	    lappend ld [list [$c name] $c]
 	}
     }
     set selID($net) $defChan($net)
-    $wincn.list.l insert end *DEFAULT*
-    $wincn.list.l insert end *NEW*
-    confSelClear $wincn.list.l [expr {[$wincn.list.l size] - 2}]
-    bind $wincn.list.l <Delete> "confDelChan $net %W %y"
-    bind $wincn.list.l <BackSpace> "confDelChan $net %W %y"
-    bind $wincn.list.l <Control-h> "confDelChan $net %W %y"
-    bind $wincn.list.l <Button-1> "changeChan $net 0 %W %y"
-    bind $wincn.list.l <Double-Button-1> "changeChan $net 1 %W %y"
-    grid $wincn.label
-    grid $wincn.list -sticky nsew
-    frame $winc.options
-    foreach opt $confData(channel) {
-	set tn [lindex $opt 1]
-	checkbutton $winc.options.$tn -text [lindex $opt 0] \
-	  -variable new$defChan($net)($tn) \
-	  -command "confDirty $net .@cfChannels$net"
-	grid $winc.options.$tn -sticky w
+    lappend ld [list *DEFAULT* $defChan($net)]
+    lappend ld  [list *NEW* {}]
+    set lbdata($wincn.l) $ld
+    confSelClear $wincn.l [expr {[$wincn.l size] - 2}]
+    bind $wincn.l <Delete> "confDelChan $net %W %y"
+    bind $wincn.l <BackSpace> "confDelChan $net %W %y"
+    bind $wincn.l <Control-h> "confDelChan $net %W %y"
+    bind $wincn.l <Button-1> "changeChan $net 0 %W %y"
+    bind $wincn.l <Double-Button-1> "changeChan $net 1 %W %y"
+    frame $win.options
+    foreach opt [array names Configure.Channel] {
+	switch [lindex [set ov [set Configure.Channel($opt)]] 0] bool {
+	    switch {} [set tn [lindex $ov 1]] {
+		set tn [trans $opt]
+	    }
+	    checkbutton $win.options.$opt -text $tn \
+	      -variable new$defChan($net)($opt) \
+	      -command "confDirty $net"
+	    grid $win.options.$opt -sticky w
+	}
     }
-    label $winc.options.msg -text Messages
-    grid $winc.options.msg -sticky w
+    label $win.options.msg -text [trans messages]
+    grid $win.options.msg -sticky w
     foreach opt [lindex [set Configure.Channel(msg)] 1] {
 	set val [string tolower $opt]
-	checkbutton $winc.options.msg$val -text $opt \
+	checkbutton $win.options.msg$val -text [trans $opt] \
 	  -variable confB($val) -command "doConfButton $net $val"
-	grid $winc.options.msg$val -sticky w
+	grid $win.options.msg$val -sticky w
     }
-    frame $winc.values
-    set cd "confDirty $net $win"
-    labelNumber 0 $winc.values.history {-text History -width 12} {} $cd
-    labelNumber 0 $winc.values.closetime {-text {Close Time} -width 12} {} $cd
-    labelEntry 0 $winc.values.icon1 {-text Icon -width 12} {} $cd
-    labelEntry 0 $winc.values.icon2 {-text {Active Icon} -width 12} {} $cd
-    labelEntry 0 $winc.values.logfile {-text {Log File} -width 12} {} $cd
-    labelEntry 0 $winc.values.key {-text Key -width 12} {} $cd
-    foreach wx "$winc.values.history $winc.values.closetime $winc.values.icon1 \
-      $winc.values.icon2 $winc.values.logfile $winc.values.key" {
+    frame $win.values
+    frame $win.look
+    set cd "confDirty $net"
+    foreach x [array names Configure.Channel] {
+	switch [lindex [set Configure.Channel($x)] 0] int {
+	    labelNumber 0 $win.values.$x "-text [list [trans $x]] -width 12" {} $cd
+	    grid $win.values.$x -sticky ew
+	}
+    }
+    labelEntry 0 $win.values.icon1 {-text Icon -width 12} {} $cd
+    labelEntry 0 $win.values.icon2 {-text {Active Icon} -width 12} {} $cd
+    labelEntry 0 $win.values.logfile {-text {Log File} -width 12} {} $cd
+    labelEntry 0 $win.values.key {-text Key -width 12} {} $cd
+    foreach wx "$win.values.icon1 $win.values.icon2 $win.values.logfile $win.values.key" {
 	grid $wx -sticky ew
     }
-    grid [button $winc.values.fg -text {Foreground Colour} \
+    grid [button $win.look.fg -text {Foreground Colour} \
       -command "confChanFG $net $win"] -sticky ew
-    grid [button $winc.values.bg -text {Background Colour} \
+    grid [button $win.look.bg -text {Background Colour} \
       -command "confChanBG $net $win"] -sticky ew
-    grid [button $winc.values.ft -text {Font} \
+    grid [button $win.look.ft -text {Font} \
       -command "confChanFt $net $win"] -sticky ew
-    grid $winc.nels $winc.options $winc.values -sticky ew
-    grid columnconfigure $winc 0 -weight 1
-    grid columnconfigure $winc 1 -weight 1
-    grid columnconfigure $winc 2 -weight 1
-    grid rowconfigure $winc 0 -weight 1
-    setCCB $net *DEFAULT*
-    bind $wincn <Enter> "focus $wincn.list.l"
-    confMkBtn $net $win Channels
-    grid $win.chan -sticky nsew
-    grid $win.btn -sticky ew
+    grid $win.nels $win.options -rowspan 2 -sticky nsew
+    grid $win.values -row 0 -column 2 -sticky nsew
+    grid $win.look -row 1 -column 2 -sticky nsew
+    grid columnconfigure $win 0 -weight 1
+    grid rowconfigure $win 0 -weight 1
+    setCCB $net $defChan($net)
+    bind $wincn <Enter> "focus $wincn.l"
 }
 switch -glob [info tclversion] {
 8* {
@@ -230,7 +224,7 @@ proc confChanFG {net win} {
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(foreground) $g
     }
-    confDirty $net $win
+    confDirty $net
 }
 #
 proc confChanBG {net win} {
@@ -239,7 +233,7 @@ proc confChanBG {net win} {
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(background) $g
     }
-    confDirty $net $win
+    confDirty $net
 }
 #
 proc confChanFt {net win} {
@@ -254,7 +248,7 @@ proc confChanFG {net win} {
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(foreground) $g
     }
-    confDirty $net $win
+    confDirty $net
 }
 #
 proc confChanBG {net win} {
@@ -263,7 +257,7 @@ proc confChanBG {net win} {
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(background) $g
     }
-    confDirty $net $win
+    confDirty $net
 }
 #
 proc confChanFt {net win} {
@@ -289,13 +283,15 @@ proc confChanBG {net win} {
 }
 #
 proc saveChan {net} {
-    global selID
+    global selID Configure.Channel
     switch nil $selID($net) return
     upvar #0 new$selID($net) new
-    set w .@cfChannels$net.chan.values
-    foreach e {closetime history logfile key} {
-	set v [$w.$e.entry get]
-	switch -- $new($e) $v {} default {set new($e) $v}
+    set w .@conf$net.f.chld.values
+    foreach x [array names Configure.Channel] {
+	switch [lindex [set Configure.Channel($x)] 0] int - file - key {
+	    set v [$w.$x.entry get]
+	    switch -- $new($x) $v {} default {set new($x) $v}
+	}
     }
     set v1 [list [$w.icon1.entry get] [$w.icon2.entry get]]
     switch {{} {}} $v1 {set v1 {}}
@@ -308,17 +304,31 @@ proc doConfButton {net indx} {
     global confB
     upvar #0 new$selID($net) new
     set vdx [lsearch $new(msg) [set v [string toupper $indx]]]
-    if !$confB($indx) {
+    if {!$confB($indx)} {
 	if {$vdx < 0} { lappend new(msg) $v }
     } {
 	if {$vdx >= 0} { listdel new(msg) $vdx }
     }
-    confDirty $net .@cfChannels$net
+    confDirty $net
 }
 #
 proc copybackChan {net} {
     global defChan
     saveChan $net
     foreach ch [info globals newchann*] { [string range $ch 3 end] unpack new }
-    confDirty $net .@cfChannels$net
+    confDirty $net
 }
+#
+proc confMessages {net win} {
+}
+#
+proc confNotices {net win} {
+}
+#
+proc confDCC {net win} {
+}
+#
+proc confChat {net win} {
+}
+#
+
