@@ -1,27 +1,32 @@
 
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/ctcp.tcl,v $
-# $Date: 1997/05/30 12:41:14 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/02/09 16:57:05 $
+# $Revision: 1.18.1.31 $
 #
 package provide zircon 1.18
 #
 proc ctcpReply {net chan nk op str} {
-    if [$net verboseCTCP] {
+    if {[$net verboseCTCP]} {
 	$net display @CTCP "*** CTCP $op Reply to $nk - $str"
     }
     $net queue "NOTICE $nk :\001$op $str\001"
 }
 #
 proc handleCTCP {net op chid chan usr prefix ign param} {
-    if [ignoreSet $ign ctcp] { return {}}
-    if ![regexp [$net ctcpPattern] $chan] { return {} }
+    if {[ignoreSet $ign ctcp]} { return {}}
+    if {![regexp [$net ctcpPattern] $chan]} { return {} }
     handleOn $net CTCP [list $op $prefix $param]
     global zircon
     set nk [$usr name]
-    switch -exact -- $op {
+    switch -glob -- $op {
     ACTION -
     SED -
     ZIRCON {}
+    "*\007*" {
+	    $net inform "Ignoring CTCPs from $nk"
+	    flipIgnore $usr CTCP
+	    return {}
+	}
     default {
 	    switch nil $chid {
 		$net inform "CTCP $op $param from $nk"
@@ -57,9 +62,9 @@ tcl [info patchlevel] tk $tk_patchLevel"
     PING { ctcpReply $net $chan $nk $op $param}
     ACTION {
 	    set lnk [$usr lname]
-	    if [me $chan $net] {
+	    if {[me $chan $net]} {
 		switch nil [set chid [Message :: find $nk $net]] {
-		    if [$net busy] {
+		    if {[$net busy]} {
 			$net queue "NOTICE $nk :[$net busymsg]"
 			$net inform \
 			  "Action from $nk at [getDate] : $param"
@@ -74,9 +79,9 @@ tcl [info patchlevel] tk $tk_patchLevel"
 	    $chid addText $lnk "* $nk $param"
 	}
     SED {
-	    if [me $chan $net] {
+	    if {[me $chan $net]} {
 		switch nil [set chid [Message :: find $nk $net]] {
-		    if [$net busy] {
+		    if {[$net busy]} {
 			$net NOTICE $nk [$net busymsg]
 			set mv [decrypt $param [$usr crypt]]
 			$net inform \
