@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/debug.tcl,v $
-# $Date: 1997/06/18 14:28:07 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/02/23 09:21:29 $
+# $Revision: 1.18.1.33 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,13 +12,13 @@
 package provide Debug 1.18
 #
 proc zshow {line} {
-    if [winfo exists .@dbgctl] {
+    if {[winfo exists .@dbgctl]} {
 	global zscr
 	set w .@dbgctl.dbg.bdy.txt
 	$w configure -state normal
 	$w insert end ">> $line\n"
 	$w configure -state disabled
-	if $zscr(dbg) { $w see end }
+	if {$zscr(dbg)} { $w see end }
 	update idletasks
     }
 }
@@ -48,17 +48,18 @@ proc zDbgHist {inc ent} {
 }
 #
 proc zDbgDo {} {
-    global DBGPos zscr
+    global DBGPos zscr errorInfo
     set w .@dbgctl.dbg.bdy
     set cmd [$w.entry get]
-    catch {uplevel #0 $cmd} msg
+    set res [catch {uplevel #0 $cmd} msg]
     $w.txt configure -state normal
     $w.txt insert end {% }
     $w.txt insert end $cmd input
     $w.txt insert end "\n"
     switch {} $msg {} default {$w.txt insert end "$msg\n" output}
+    if {$res} {$w.txt insert end $errorInfo }
     $w.txt configure -state disabled
-    if $zscr(dbg) { $w.txt see end }
+    if {$zscr(dbg)} { $w.txt see end }
     $w.entry delete 0 end
     set DBGPos end
 }
@@ -83,11 +84,7 @@ $errorInfo"
       \"$cmd\" from \"$prefix\" ($param $rest). The stack trace has\
       been saved in file \"$file\". Please send this information to\
       zircon@catless.ncl.ac.uk."
-    switch 7.5 [info tclversion] {
-	mkInfoBox $currentNet ZERROR .@zrun {Internal Error} $msg
-    } default {
-	tk_messageBox -icon error -title {Internal Error} -message $msg -type ok
-    }
+      tellError $currentNet {Internal Error} $msg ZERROR
 }
 #
 proc tkerror {err} { zError $err INTERNAL {} {} {} }
@@ -95,28 +92,28 @@ proc tkerror {err} { zError $err INTERNAL {} {} {} }
 proc bgerror {err} { zError $err INTERNAL {} {} {} }
 #
 proc zIn {line net} {
-    if ![winfo exists .@dbgctl] return
-    if ![$net monitorIn] return
+    if {![winfo exists .@dbgctl]} return
+    if {![$net monitorIn]} return
     global zscr DBStamp
     set w .@dbgctl.$net.bdy
     $w.txt configure -state normal
-    if $DBStamp($net) { $w.txt insert end [clock format [clock seconds]] }
+    if {$DBStamp($net)} { $w.txt insert end [clock format [clock seconds]] }
     $w.txt insert end ">$line" input "\n"
     $w.txt configure -state disabled
-    if $zscr($net) { $w.txt see end }
+    if {$zscr($net)} { $w.txt see end }
     update idletasks
 }
 #
 proc zOut {line net} {
-    if ![winfo exists .@dbgctl] return
-    if ![$net monitorOut] return 
+    if {![winfo exists .@dbgctl]} return
+    if {![$net monitorOut]} return 
     global zscr DBStamp
     set w .@dbgctl.$net.bdy
     $w.txt configure -state normal
-    if $DBStamp($net) { $w.txt insert end [clock format [clock seconds]] }
+    if {$DBStamp($net)} { $w.txt insert end [clock format [clock seconds]] }
     $w.txt insert end "<$line" output "\n"
     $w.txt configure -state disabled
-    if $zscr($net) { $w.txt see end }
+    if {$zscr($net)} { $w.txt see end }
     update idletasks
 }
 #
@@ -124,8 +121,8 @@ proc zDump {file} {
     set fd [open $file w]
     foreach _x [lsort [info globals]] {
 	global $_x
-	if [string match auto_* $_x] continue
-	if [array exists $_x] {
+	if {[string match auto_* $_x]} continue
+	if {[array exists $_x]} {
 	    foreach _v [lsort [array names $_x]] {
 		puts $fd "${_x}($_v) : {[set ${_x}($_v)]}"
 	    }
@@ -148,7 +145,7 @@ proc zSOpen {net txt mode file} {
     switch absolute [file path $file] {} default {
 	set file [file join [pwd] $file]
     }
-    if [catch {open $file $mode} fd] {
+    if {[catch {open $file $mode} fd]} {
 	$net errmsg "Cannot open file $file : $fd"
 	return 0
     }
@@ -159,8 +156,8 @@ proc zSOpen {net txt mode file} {
 proc zCtlQuit {} { catch {uplevel #0 unset zscr} ; destroy .@dbgctl }
 #
 proc zDBGRet {net} {
-    if [winfo exists .@dbgctl] {
-	if [$net active] { set op host } { set op name }
+    if {[winfo exists .@dbgctl]} {
+	if {[$net active]} { set op host } { set op name }
 	retitleFrame .@dbgctl $net "Trace of [$net $op]" 1
     }
 }
@@ -170,7 +167,7 @@ proc zDBGCsw {ctl net title tr ent} {
 }
 #
 proc zDBIn {net} {
-    if [$net monitorIn] {
+    if {[$net monitorIn]} {
 	.@dbgctl.$net.bdy.f3.tracein configure -text "Show In"
 	set x 0
     } {
@@ -181,7 +178,7 @@ proc zDBIn {net} {
 }
 #
 proc zDBOut {net} {
-    if [$net monitorOut] {
+    if {[$net monitorOut]} {
 	.@dbgctl.$net.bdy.f3.traceout configure -text "Show Out"
 	set x 0
     } {
@@ -193,7 +190,7 @@ proc zDBOut {net} {
 #
 proc zDBStamp {net} {
     global DBStamp
-    if $DBStamp($net) {
+    if {$DBStamp($net)} {
 	.@dbgctl.$net.bdy.f3.tstamp configure -text {Timestamp}
 	set x 0
     } {
@@ -205,7 +202,7 @@ proc zDBStamp {net} {
 #
 proc zNScroll {net} {
     global zscr
-    if $zscr($net) {
+    if {$zscr($net)} {
 	set zscr($net) 0
 	.@dbgctl.$net.bdy.f3.noscroll configure -text [trans scroll]
     } {
@@ -216,8 +213,8 @@ proc zNScroll {net} {
 #
 proc zDBGControl {} {
     global zscr zircon zlayout
-    if [winfo exists .@dbgctl] { popup .@dbgctl ; return }
-    .@ctl.helpFrm.info.menu entryconfigure end -state normal
+    if {[winfo exists .@dbgctl]} { popup .@dbgctl ; return }
+    [MainControl].helpFrm.info.menu entryconfigure end -state normal
     toplevel [set ctl .@dbgctl] -class Zircon
     wm title $ctl "Zircon Debugger"
     wm resizable $ctl 1 1
@@ -254,13 +251,13 @@ proc zDBRegion {f tr net ent} {
     grid columnconfigure $f 0 -weight
     grid [frame $f.f3 -borderwidth 0] -column 2 -rowspan 2 -row 0 -sticky ns
     zDBGText $f
-    if $tr {
+    if {$tr} {
 	set x Show
-	if [$net monitorIn] { set x Hide }
+	if {[$net monitorIn]} { set x Hide }
 	button $f.f3.tracein -text "$x In" -width 8 \
 	  -command "zDBIn $net" -foreground red
 	set x Show
-	if [$net monitorOut] { set x Hide }
+	if {[$net monitorOut]} { set x Hide }
 	button $f.f3.traceout -text "$x Out" -width 8 \
 	  -command "zDBOut $net" -foreground blue
 	button $f.f3.tstamp -text "Timestamp" -width 8 -command "zDBStamp $net"
@@ -275,7 +272,7 @@ proc zDBRegion {f tr net ent} {
     grid $f.f3.save
     grid $f.f3.clear
     grid $f.f3.noscroll
-    if $ent {
+    if {$ent} {
 	emacsEntry $f.entry -relief sunken
 	grid $f.entry -row 2 -columnspan 3 -column 0 -sticky ew
 	bind $f.entry <Return> zDbgDo
@@ -303,7 +300,13 @@ proc zDBGText {f} {
 }
 #
 proc zDBGAdd {net} {
-    if [winfo exists .@dbgctl] {
+    if {[winfo exists .@dbgctl]} {
 	zDBGCsw .@dbgctl $net "Trace of [$net name]" 1 0
     }
 }
+#
+proc zAfter {} {
+    foreach x [after info] {
+        zshow [after info $x]
+    }
+}
