@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/initial.tcl,v $
-# $Date: 1997/06/18 14:28:10 $
-# $Revision: 1.18.1.131 $
+# $Date: 1998/02/26 15:51:28 $
+# $Revision: 1.18.1.160 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -21,6 +21,10 @@ set cfgv {showLocal showPublic showPrivate topicOnly
 #
 proc preferences {op val} {}
 #
+proc dispAd {msg} {
+    catch {.ad.info conf -text $msg ; update }
+}
+#
 proc net {var val} {
     global currentNet DEBUG
     switch -glob -- $var {
@@ -52,6 +56,7 @@ proc net {var val} {
     autoAway -
     ping -
     monitorTime -
+    quittime -
     dccTime -
     notifyInterval {$currentNet configure -$var [expr {$val * 1000}]}
     closeTime - testTime {# dont let users change these }
@@ -73,6 +78,7 @@ proc leave {args} { global currentNet ; $currentNet configure +leaves [join $arg
 proc signoff {args} { global currentNet ; $currentNet configure +signoffs [join $args] }
 #
 proc zbind {a1 a2 args} {
+    global currentNet
     switch {} $args {
 	set chan {}
 	set sequence $a1
@@ -82,7 +88,6 @@ proc zbind {a1 a2 args} {
 	set sequence $a2
 	set action [lindex $args 0]
     }
-    global currentNet
     switch {} $chan {
 	$currentNet configure +bindings [list $sequence $action]
     } default {
@@ -91,7 +96,7 @@ proc zbind {a1 a2 args} {
 }
 #
 proc srvName {srv net} {
-    if [regexp {(.*):(.*)} $srv m hst prt] {
+    if {[regexp {(.*):(.*)} $srv m hst prt]} {
 	switch nil [set sid [Server :: make $net $hst]] {
 	    set sid [Server $hst -port $prt]
 	} default {
@@ -123,7 +128,7 @@ proc setCE {var val evar} {
 proc envCheck {arg evar op dflt} {
     global currentNet
     set lst [$currentNet $op]
-    if [setCE v $arg $evar] {
+    if {[setCE v $arg $evar]} {
 	if {[set x [lsearch $lst $v]] > 0} { listdel lst $x }
 	$currentNet configure -$op [linsert $lst 0 $v]
     } \
@@ -134,9 +139,27 @@ proc layout {net window geom} {
     uplevel #0 set zlayout($net,$window) $geom
 }
 #
+proc checkRE {exp} { return [expr {![catch {regexp $exp a}]}] }
+#
+proc helper {ptn cmd args} {
+    global currentNet
+    if {![checkRE $ptn]} {
+	tellError {} Error "Bad helper file regular expression $ptn"
+    } {
+	set usr [lindex $args 0]
+	switch {} $usr { set usr .* } default {
+	    if {![checkRE $usr]} {
+		tellError {} Error "Bad helper user regular expression $usr"
+		return
+	    }
+	}
+	$currentNet configure +helpers [list $ptn $cmd ]
+    }
+}
+#
 proc srcit {file what} {
-    if [file exists $file] {
-	if [catch {uplevel #0 source \{$file\}} msg] {
+    if {[file exists $file]} {
+	if {[catch {uplevel #0 source \{$file\}} msg]} {
 	    puts stderr "**** Error in the $what file - $msg"
 	    bgerror Error
 	    exit 1
@@ -155,12 +178,14 @@ proc setupImages {} {
 }
 #
 proc InitImages {} {
+    dispAd {Initialising Images...}
     global zircon DIms
     set f [file join $zircon(lib) gifs]
     foreach x {arc none polygon text line oval rectangle} {
 	set DIms($x) [image create photo -file [file join $f $x.gif]]
     }
-    global zDIOff zDIOn zDIOff1 zDIOn1 zKeyGif zSpkGif zNSpkGif
+    global zDIOff zDIOn zDIOff1 zDIOn1 zKeyGif zSpkGif zNSpkGif zII \
+      zNOII zLock zUnlock
     set zDIOff [image create photo -file [file join $f off.gif]]
     set zDIOn  [image create photo -file [file join $f on.gif]]
     set zDIOff1 [image create photo -file [file join $f off1.gif]]
@@ -168,19 +193,22 @@ proc InitImages {} {
     set zKeyGif [image create photo -file [file join $f key.gif]]
     set zSpkGif [image create photo -file [file join $f speak.gif]]
     set zNSpkGif [image create photo -file [file join $f nospeak.gif]]
+    set zII [image create photo -file [file join $f ii.gif]]
+    set zNOII [image create photo -file [file join $f noii.gif]]
+    set zLock [image create photo -file [file join $f lock.gif]]
+    set zUnlock [image create photo -file [file join $f unlock.gif]]
     setupImages
 }
 #
-
-
 proc InitPlugins {} {
     global zircon auto_path
     foreach x [glob -nocomplain [file join $zircon(lib) plugins *]] {
-	if [file isdirectory $x] {
+	if {[file isdirectory $x]} {
 	    set auto_path [linsert $auto_path 0 $x]
 	    set pname [file tail $x]
-	    if [file exists [set f [file join $x setup.tcl]]] {
-		if [catch {source $f} msg] {
+	    dispAd "Initialising plugin $pname..."
+	    if {[file exists [set f [file join $x setup.tcl]]]} {
+		if {[catch {source $f} msg]} {
 		    tellError {} Plugins "Error setting up plugin $pname - \"$msg\""
 		}
 	    } {
@@ -190,6 +218,16 @@ proc InitPlugins {} {
     }
 }
 #
+proc InitLang {args} {
+    global zircon
+    switch english $zircon(language) {} default {
+	srcit [file join $zircon(lib) lang $zircon(language).tcl] \
+	  "system Zircon $zircon(language) message"
+    }
+    srcit [file join $zircon(prefdir) lang $zircon(language).tcl] \
+      "your Zircon $zircon(language) message"
+}
+#
 proc Initialise {} {
     global argv zircon defaults DEBUG currentNet defaultNet inexp1 \
       inexp2 userFlags zWList zWClose zWInc ztrans 
@@ -217,35 +255,38 @@ proc Initialise {} {
     wm withdraw .
     set h [winfo screenheight .]
     set w [winfo screenwidth .]
-    if [string match {*#*} [winfo name .]] {
-	if ![askUser {} Duplicate {You have another copy of zircon\
+    if {[string match {*#*} [winfo name .]]} {
+	if {![askUser {} Duplicate {You have another copy of zircon\
 running. This may cause some problems with the appearance of this run.
 
-Continue?}] {
+Continue?}]} {
 	    exit
 	}
     }
     image create photo advert -file [file join $zircon(lib) gifs zircon.gif]
-    set iw [expr {[image width advert] +10}]
-    set ih [expr {[image height advert] + 10}]
+    set iw [expr {[image width advert] + 10}]
+    set ih [expr {[image height advert] + 30}]
     toplevel .ad
+    set zircon(fg) [[label .ad.f] cget -foreground]
+    destroy .ad.f
     wm overrideredirect .ad 1
-    wm geometry .ad ${iw}x${ih}+[expr ($w -$ih) /2]+[expr ($h - $ih)/2]
+    wm geometry .ad ${iw}x${ih}+[expr {($w -$ih) /2}]+[expr {($h - $ih )/2}]
     grid [label .ad.l -image advert -borderwidth 5 -relief ridge]
-    after 3000 { catch {destroy .ad} }
+    grid [label .ad.info -bg black -fg white -text {}] -sticky ew
     update
 #
 # Hack to hide tk grab errors... (may have to be cleverer!!!)
 #
     rename grab sys_grab
-    proc grab {args} {if ![catch {eval sys_grab $args} res] { return $res } }
+    proc grab {args} {if {![catch {eval sys_grab $args} res]} { return $res } }
 #
     InitClasses
 #
+    dispAd "Initialising bindings..."
     foreach ty {Entry Text Button} {
-        foreach x [bind $ty] { bind $ty $x {+ notIdle %W} }
+	foreach x [bind $ty] { bind $ty $x {+ notIdle %W} }
     }
-    if [file exists [file join $zircon(lib) zircon.ad]] {
+    if {[file exists [file join $zircon(lib) zircon.ad]]} {
 	option readfile [file join $zircon(lib) zircon.ad] startupFile
     }
     option add *Checkbutton*relief flat widgetDefault
@@ -320,15 +361,16 @@ Continue?}] {
 	i	invisible
 	r	restricted
     }
+    dispAd "Processing arguments..."
 # Process args
     set DEBUG 0
     set opts {}
     foreach arg $argv {
-	if [string match {-*} $arg] {
+	if {[string match {-*} $arg]} {
 	    foreach bit [split [string range $arg 1 end]] {
 		switch $bit {
 		C - j - o - z { set zircon($bit) 1 }
-		d - r - i - N - S - p { lappend opts $bit}
+		d - r - i - l - N - S - p { lappend opts $bit}
 		D { set DEBUG 1 }
 		default { puts stderr "Unknown option -$bit" }
 		}
@@ -338,17 +380,26 @@ Continue?}] {
 	    set opts [lrange $opts 1 end]
 	    switch $opt {
 	    i - N - S - r - p { set zircon($opt) $arg }
+	    l { set zircon(language) $arg }
 	    default { }
 	    }
 	}
     }
-    if $DEBUG { package require Tracing } { package require Notrace }
+    if {$DEBUG} { package require Tracing } { package require Notrace }
     set defaultNet [set currentNet [Net default]]
+    dispAd "Initialising Look..."
     InitLook
     InitImages
     InitPlugins
     after 600000 schedGC
     set zWClose [after $zWInc closeWindows]
+    InitGlobals
+    if {$DEBUG} zDBGControl
+    destroy .ad
+#    update
+#    tkwait visibility .@ctl
+    checkHeight [MainControl]
+    bind [MainControl] <Configure> {checkHeight [winfo toplevel %W]}
 }
 #
 proc makeDefaults {net} {
@@ -360,6 +411,7 @@ proc makeDefaults {net} {
 }
 #
 proc InitGlobals {} {
+    dispAd "Initialising Globals..."
     global env zircon defaults user trust
     upvar #0 currentNet net
     getOption smiley ":-\)"
@@ -383,67 +435,54 @@ proc InitGlobals {} {
 # flag turns off reading rc files. First source the English language
 # in case of errors.
 #
+    dispAd {Initialising messages...}
     srcit [file join $zircon(lib) lang english.tcl] "the system Zircon english message"
     global DEBUG hostIPaddress
     catch {set hostIPaddress $env(HOSTIPADDR)}
-    if ![srcit [file join $zircon(prefdir) look $zircon(look).tcl] \
-      "your Zircon $zircon(look) look"] {
+    dispAd {Initialising system look...}
+    if {![srcit [file join $zircon(prefdir) look $zircon(look).tcl] \
+      "your Zircon $zircon(look) look"]} {
 	srcit [file join $zircon(lib) look $zircon(look).tcl] \
 	  "the system Zircon $zircon(look)"
     }
-    switch english $zircon(language) {} default {
-	srcit [file join $zircon(lib) lang $zircon(language).tcl] \
-	  "system Zircon $zircon(language) message"
-    }
-    srcit [file join $zircon(prefdir) lang $zircon(language).tcl] \
-      "your Zircon $zircon(language) message"
+    dispAd "Initialising $zircon(language) messages..."
+    InitLang
+    trace variable zircon(language) w InitLang
+    dispAd {Initialising layout...}
     srcit [file join $zircon(prefdir) layout] "your Zircon layout"
-    MainControl
-    MainInfo
+    versionCheck
+    dispAd {Reading your preferences...}
     catch {set zircon(prefdir) $env(ZIRCONPREFDIR)}
-    if [info exists zircon(d)] { set zircon(prefdir) $zircon(d) }
-    if !$zircon(z) {
-	if [info exists zircon(r)] {
+    if {[info exists zircon(d)]} { set zircon(prefdir) $zircon(d) }
+    if {!$zircon(z)} {
+	if {[info exists zircon(r)]} {
 	    srcit $zircon(r) "your $zircon(r)"
 	} {
 	    set sp $zircon(prefdir)
-	    if [srcit [file join $zircon(lib) rc] {the system rc}] {
-	        foreach sv [$net servers] { $sv configure -sys 1 }
-	        foreach sv [$net services] { $sv configure -sys 1 }
-	        foreach sv [$net channels] { $sv configure -sys 1 }
+	    if {[srcit [file join $zircon(lib) rc] {the system rc}]} {
+		foreach sv [$net servers] { $sv configure -sys 1 }
+		foreach sv [$net services] { $sv configure -sys 1 }
+		foreach sv [$net channels] { $sv configure -sys 1 }
 		uplevel #0 \$defChan($net) configure -sys 0
-		global cfgv
-		set alert 0
-		foreach x $cfgv {
-		    switch {} [info globals $x] continue
-		    if !$alert {
-			bell
-			tk_dialog .@wa Warning "The preferences\
-file format has changed - please get your system adminstrator to\
-update the zircon system rc file. The use of this file is now \
-deprecated and it may not be supported in future versions of \
-zircon." warning 0 ok
-			set alert 1
-		    }
-		    $net configure -$x [set $x]
-		}
+		oldCheck $net
 	    }
 	    set zircon(prefdir) $sp
-	    if ![srcit [file join $zircon(prefdir) preferences] \
-		"your [file join $zircon(prefdir) preferences]"] {
-		if [srcit [file join ~ .zirconrc] {your .zirconrc}] { upgradeRC }
+	    if {![srcit [file join $zircon(prefdir) preferences] \
+		"your [file join $zircon(prefdir) preferences]"]} {
+		if {[srcit [file join ~ .zirconrc] {your .zirconrc}]} { upgradeRC }
 	    }
 	}
     }
     envCheck $zircon(N) $zircon(envnick) nicks $user
     envCheck $zircon(i) $zircon(envname) ircnames %u@%h
     InitNet $net
+    trace vdelete zircon(language) w InitLang
     set nets [Net :: list]
     if {[llength $nets] <= 2} {
 	set dnet [lindex $nets end]
 #    setCE v $zircon(p) $zircon(envport)
 	set srv nil
-	if ![string match {} $zircon(S)] { set srv [srvName $zircon(S) $dnet]}\
+	if {![string match {} $zircon(S)]} { set srv [srvName $zircon(S) $dnet]}\
 	elseif {[info exists env($zircon(envserver))]} {
 	    foreach v [split $env($zircon(envserver))] {
 		lappend sid [srvName $v $dnet]
@@ -451,25 +490,21 @@ zircon." warning 0 ok
 	    set srv [lindex $sid 0]
 	} \
 	elseif {![string compare nil [$dnet hostid]]} {
-	    if ![string compare nil [set srv [Server :: find default $dnet]]] {
+	    if {![string compare nil [set srv [Server :: find default $dnet]]]} {
 		set zircon(C) 2
 	    }
 	}
 	switch nil $srv {} default {$dnet configure -hostid $srv}
     }
-    if $DEBUG zDBGControl
-    tkwait visibility .@ctl
-    checkHeight .@ctl
-    bind .@ctl <Configure> {checkHeight [winfo toplevel %W]}
-    versionCheck
 }
 #
 proc InitNet {net} {
+    dispAd "Initialising netspace [$net name]..."
     global zircon trust defaultNet cfgv defChan user host
     set notdf [string compare $net $defaultNet]
     foreach x {eval draw} {
-	if ![info exists trust($net,$x)] {
-	    if [info exists trust($defaultNet,$x)] {
+	if {![info exists trust($net,$x)]} {
+	    if {[info exists trust($defaultNet,$x)]} {
 		set trust($net,$x) $trust($defaultNet,$x)
 	    } {
 		set trust($net,$x) $trust($x)
@@ -479,8 +514,8 @@ proc InitNet {net} {
 #
 # Set up all the defaults from the default net (if any)
 #
-    if [$net raw] {$net configure -command 1}
-    if $notdf {	
+    if {[$net raw]} {$net configure -command 1}
+    if {$notdf} {	
 	global Net currentNet
 	set sc $currentNet
 	set currentNet $net
@@ -500,64 +535,80 @@ proc InitNet {net} {
 	switch {} [$net ircnames] {$net configure -ircnames %u@%h}
 
     }
-#    foreach x [$net users] {
-#	Friend [$x name] -notify [$x notify] -id [$x id]
-#	$x delete
-#    }
 #
 # Flag channels that are created in the rc file. This makes sure they
 # dont get thrown away when the channel is closed
 #
     foreach x [$net channels] { $x configure -keep 1 }
     foreach x [$net messages] { $x configure -keep 1 }
+    oldCheck $net
+}
+#
+proc oldCheck1 {net} {}
+#
+proc oldCheck {net} {
+    global cfgv
     set alert 0
+    dispAd {Checking for old format...}
     foreach x $cfgv {
 	switch {} [info globals $x] continue
-	if !$alert {
+	if {!$alert} {
 	    bell
 	    tk_dialog .@wa Warning "The preferences file format \
 has changed - please re-save your preferences" warning 0 ok
 	    set alert 1
 	}
-	$net configure -$x [set $x]
+	$net configure -$x [uplevel #0 set $x]
     }
 }
 #
 # Configuration panel stuff
 #
 array set cVars {
-    IRC		{nicks ircnames}
+    Nicknames		{nicks}
+    IRCNames		{ircnames}
+    Servers	{}
+    DCC		{}
+    Messages	{}
+    Notices	{}
+    Chat	{}
     Channels	{}
-    People	{ignores showFriends friendsOn}
+    Friends	{showFriends friendsOn}
+    Ignores	{ignores}
     Info	{showLocal showPublic showPrivate topicOnly minMembers \
 		 noConfirm toInfo popInfo verboseCTCP helpService \
 		 noPopup noRefresh killPath listPattern topicPattern \
 		 notifyInterval}
 }
 #
+set tabNames {Nicknames IRCNames Servers Channels Messages Notices Chat DCC Friends Ignores Info}
+#
 array set confData {
     channel	{{{Auto Join} join} {{Pop Up} open} \
 		 {{Pop Down} close} {{On Menu} menu} {Draw draw} \
-		 {Jump jump} {Quiet quiet} {{Nocase} nocase}}
+		 {Jump jump} {Quiet quiet} {{Ignore Case} nocase}}
 }
 #
 proc versionCheck {} {
     global zircon
     set f [file join $zircon(prefdir) version]
+    if {[file exists $f]}  {
+	catch { rename oldCheck {} ; rename oldCheck1 oldCheck}
+    }
     if {[catch {source $f}] ||
       ![info exists currentVersion] ||
-      [string compare $currentVersion $zircon(version)$zircon(patchlevel)]} {
+      [string compare $currentVersion $zircon(version).$zircon(patchlevel)]} {
 	displayAlert
-	if ![file exists $zircon(prefdir)] {
-	    if [catch {filemkdir $zircon(prefdir)} msg] {
+	if {![file exists $zircon(prefdir)]} {
+	    if {[catch {filemkdir $zircon(prefdir)} msg]} {
 		tellError {} Version "Cannot create preferences directory - $msg"
 		return
 	    }
 	}
-	if [catch {open $f w} fd] {
+	if {[catch {open $f w} fd]} {
 	    tellError {} Version "Cannot write version file - $fd"
 	} {
-	    puts $fd "set currentVersion $zircon(version)$zircon(patchlevel)"
+	    puts $fd "set currentVersion $zircon(version).$zircon(patchlevel)"
 	    close $fd
 	}
     }
@@ -566,20 +617,14 @@ proc versionCheck {} {
 proc displayAlert {} {
    global zircon
    set warn {}
-   switch [info tclversion] 7.5 {
+   switch -glob -- [info patchlevel] 7* - 8.0a* - 8.0b* - 8.0 - 8.0p1 {
 	set warn {
-You are still running tcl7.5 - you really should upgrade to the latest\
-release of tcl which is tcl7.6/tk4.2. (And there are alphas of 8.0
-which give significant performance improvements)}
-    }
-    tellInfo {New Version} "This is Zircon $zircon(version) patchlevel $zircon(patchlevel)$warn
 
-This release fixes the looping problems that people have been having.
-(This was a conflict between the tk gridder and packer if you are
-interested....) You may find that the appearance of certain windows 
-has changed a little. If there is something that looks wrong then
-please let me know and I'll fix it for the next version - it's
-impossible to check out every window combination....
+You should upgrade to the latest release of tcl which is tcl8.0p2.}
+    }
+    tellInfo {} {New Version} "This is Zircon $zircon(version) patchlevel $zircon(patchlevel)$warn
+
+See CHANGES for what has altered.
 
 L."
 }
