@@ -1,14 +1,14 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/saverc.tcl,v $
-# $Date: 1997/02/05 12:42:39 $
-# $Revision: 1.18.1.19 $
+# $Date: 1998/02/10 10:48:47 $
+# $Revision: 1.18.1.24 $
 #
 package provide zircon 1.18
 #
 set RCFV 1
 #
 proc putProc {desc cmnt name list dflt args} {
-    if $dflt {
+    if {$dflt} {
 	set dl $args
     } {
 	global defaultNet
@@ -19,7 +19,7 @@ proc putProc {desc cmnt name list dflt args} {
 	switch {} $cmnt {set pc 0} default {set pc 1}
 	foreach l $list {
 	    if {[lsearch -exact $dl $l] < 0} {
-		if $pc {puts $desc "#\n# $cmnt\n#" ; set pc 0}
+		if {$pc} {puts $desc "#\n# $cmnt\n#" ; set pc 0}
 		puts $desc "$name [list $l]"
 	    }
 	}
@@ -34,7 +34,7 @@ proc saverc {net} {
     } default {
 	set rcd [file join $zircon(prefdir) netspaces]
 	set rc [file join $rcd $nn]
-	if [file isdirectory $rc] {
+	if {[file isdirectory $rc]} {
 	    set rcd [list $zircon(prefdir) $rcd $rc]
 	    set rc [file join $rc preferences]
 	} {
@@ -42,7 +42,7 @@ proc saverc {net} {
 	}
 	set dflt 0
     }
-    if [file exist $rc] {
+    if {[file exist $rc]} {
 	file stat $rc st
 	set mode $st(mode)
 	set rc [glob $rc]
@@ -50,8 +50,8 @@ proc saverc {net} {
 	set bak 1
     } {
 	foreach dx $rcd {
-	    if ![file exists $dx] {
-		if [catch {filemkdir $dx} msg] {
+	    if {![file exists $dx]} {
+		if {[catch {filemkdir $dx} msg]} {
 		    tellError {} Error "Error when creating $rcd - $msg"
 		    return 0
 		}
@@ -60,16 +60,16 @@ proc saverc {net} {
 	set mode 0600
 	set bak 0
     }
-    if [catch {open $rc w $mode} desc] {
+    if {[catch {open $rc w $mode} desc]} {
 	tellError {} Error \
 	  "Error when opening preferences file for write - $desc" 
-	if $bak { filerename $rc.bak $rc }
+	if {$bak} { filerename $rc.bak $rc }
 	return 0
     }
-    if [catch {doSave $dflt $net $desc} msg] {
+    if {[catch {doSave $dflt $net $desc} msg]} {
 	catch {close $desc}
 	filerename $rc $rc.tmp 
-	if $bak { filerename $rc.bak $rc }
+	if {$bak} { filerename $rc.bak $rc }
 	bgerror $msg
 	tellError {} Error "Error while saving preferences file - $msg"
 	return 0
@@ -79,7 +79,7 @@ proc saverc {net} {
 #
 proc doSave {dflt net desc} {
     global zircon defaults DEBUG trust RCFV defaultNet user Configure.Net
-    if $dflt {
+    if {$dflt} {
 	puts $desc "#\n# Zircon preferences file saved - [getDate]\n#"
     } {
 	puts $desc "#\n# Zircon Netspace [$net name] saved - [getDate]\n#"
@@ -88,14 +88,14 @@ proc doSave {dflt net desc} {
 # Save things that are different from the default...
 #
     puts $desc "preferences format $RCFV"
-    if $dflt {
+    if {$dflt} {
 	foreach z [array names defaults] {
 	    switch -- $zircon($z) $defaults($z) {} default {
 	        puts $desc "net zircon($z) [list $zircon($z)]"
 	    }
 	}
 	foreach z {soundcmd cciport wwwclient} {
-	    if [info exists zircon($z)] {
+	    if {[info exists zircon($z)]} {
 		puts $desc "net zircon($z) [list $zircon($z)]"
 	    }
 	}
@@ -103,19 +103,6 @@ proc doSave {dflt net desc} {
 #
 # Optional values
 #
-    putProc $desc Nicknames nick [$net nicks] $dflt $user
-    putProc $desc {IRC names} ircname [$net ircnames] $dflt %u@%h
-    Server :: save $desc $net
-    Service :: save $desc $net
-    Friend :: save $desc $net
-    set cm 0
-    foreach p [$net ignores] {
-	if ![string match {} [lindex $p 1]] {
-	    if $cm { puts $desc "#\n# Ignores\n#" ; set cm 0 }
-	    puts $desc "ignore [list [lindex $p 0]] [list [lindex $p 1]]"
-	}
-    }
-    foreach x {Channel Message Notice Chat} { $x :: save $desc $net }
     saveLook $desc $net
     saveShare $desc $net
     puts $desc "#\n# Netspace Control Values\n#"
@@ -125,7 +112,7 @@ proc doSave {dflt net desc} {
     global Net
     array set ndefs $Net
     foreach v [array names ndefs] {
-	if $dflt {set dv $ndefs($v)} {set dv [$defaultNet $v]}
+	if {$dflt} {set dv $ndefs($v)} {set dv [$defaultNet $v]}
 	switch -- [$net $v] $dv continue
 	switch [set Configure.Net($v)] {
 	mseconds {
@@ -142,11 +129,24 @@ proc doSave {dflt net desc} {
 	default	{ puts $desc "net $v [list [$net $v]]" }
 	}
     }
+    putProc $desc Nicknames nick [$net nicks] $dflt $user
+    putProc $desc {IRC names} ircname [$net ircnames] $dflt %u@%h
+    Server :: save $desc $net
+    Service :: save $desc $net
+    Friend :: save $desc $net
+    set cm 0
+    foreach p [$net ignores] {
+	switch {} [lindex $p 1] {} default {
+	    if {$cm} { puts $desc "#\n# Ignores\n#" ; set cm 0 }
+	    puts $desc "ignore [list [lindex $p 0]] [list [lindex $p 1]]"
+	}
+    }
+    foreach x {Channel Message Notice Chat} { $x :: save $desc $net }
     set cm 1
     upvar #0 OnCode$net OnCode
     foreach x [array names OnCode] {
 	foreach on $OnCode($x) {
-	    if $cm { puts $desc "#\n# On Conditions\n#" ; set cm 0 }
+	    if {$cm} { puts $desc "#\n# On Conditions\n#" ; set cm 0 }
 	    puts $desc "on $x $on"
 	}
     }
@@ -157,16 +157,16 @@ proc doSave {dflt net desc} {
     set cm 1 
     foreach x [array names trust "$net,*"] {
 	regexp {.*,(.*)} $x m lm
-	if $dflt {
+	if {$dflt} {
 	    switch -- $trust($x) $trust($lm) continue
 	} {
 	    switch -- $trust($x) $trust($defaultNet,$lm) continue
 	    switch -- $trust($x) $trust($lm) continue
 	}
-	if $cm { puts $desc "#\n# Trust settings\n#" ; set cm 0 }
+	if {$cm} { puts $desc "#\n# Trust settings\n#" ; set cm 0 }
 	puts $desc "net trust($lm) [list $trust($x)]"
     }
-    if $dflt {
+    if {$dflt} {
 	foreach x [Net :: list] {
 	   switch $x $net {} default {puts $desc "#\nNetspace [$x name]"}
 	}
@@ -194,24 +194,27 @@ proc ditchSize {w} {
 proc saveLayout {net} {
     global zircon
     set rc [file join $zircon(prefdir) layout]
-    if [file exist $rc] {
+    if {[file exist $rc]} {
 	file stat $rc st
 	set mode $st(mode)
 	set rc [glob $rc]
-	exec mv $rc $rc.bak
+	if {[catch {filerename $rc $rc.bak} msg]} {
+	    tellError {} Error "Error when renaming $rc - $msg"
+	    return 0
+	}
 	set bak 1
     } {
 	set mode 0600
 	set bak 0
     }
-    if [catch {open $rc w $mode} desc] {
+    if {[catch {open $rc w $mode} desc]} {
 	tellError {} Error "Error when opening layout file for write - $desc"
-	if $bak { exec mv $rc.bak $rc }
+	if {$bak} { exec mv $rc.bak $rc }
 	return 0
     }
     puts $desc "layout default info [ditchSize .@inf]"
     puts $desc "layout default control [ditchSize .@ctl]"
-    if [winfo exists .@dbgctl] {
+    if {[winfo exists .@dbgctl]} {
 	puts $desc "layout default debug [ditchSize .@dbgctl]"
     }
     close $desc
