@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/zdraw.tcl,v $
-# $Date: 1997/06/24 11:53:17 $
-# $Revision: 1.18.1.12 $
+# $Date: 1998/02/10 10:48:51 $
+# $Revision: 1.18.1.13 $
 #
 package provide zircon 1.18
 #
@@ -10,7 +10,7 @@ proc zdraw {usr cmd} {
 	[$usr net] inform "Bad draw command - \"$cmd\""
 	return
     }
-    if [$this draw] {
+    if {[$this draw]} {
 	$this makeZDraw
 	set w .@zd$this.pic.canvas
 	switch [set lnm [$usr lname]] {
@@ -20,7 +20,7 @@ proc zdraw {usr cmd} {
 	switch [lindex $cmd 1] {
 	delete {
 		switch -exact -- [set v [string tolower [lindex $cmd 2]]] {
-		*all* {	if [$this isOp $usr] { set v all } { set v $lnm } }
+		*all* {	if {[$this isOp $usr]} { set v all } { set v $lnm } }
 		all -
 		current { set v ,$v }
 		}
@@ -28,7 +28,7 @@ proc zdraw {usr cmd} {
 	    }
 	default {
 		regsub -all {[][$;]} [lrange $cmd 1 end] {} dc
-		if ![catch {set tid [eval $w $dc]} msg] {
+		if {![catch {set tid [eval $w $dc]} msg]} {
 		    $w itemconfigure $tid -tags $lnm
 		}
 	    }
@@ -43,7 +43,7 @@ proc zdDestroy {win} {
 #
 proc zdModeChange {type win} {
     upvar #0 Z$win zdata
-    if [info exists zdata(mode)] {
+    if {[info exists zdata(mode)]} {
 	$win.plt.$zdata(mode) configure -relief raised
     }
     set zdata(mode) $type
@@ -80,7 +80,7 @@ proc clButtons win {
 #
 proc zdColChange {var win frame cl} {
     upvar #0 Z$win zdata
-    if [info exists zdata($var)] {
+    if {[info exists zdata($var)]} {
 	$win.$frame.$zdata($var) configure -relief raised
     }
     set zdata($var) $cl
@@ -88,13 +88,13 @@ proc zdColChange {var win frame cl} {
 }
 #
 proc channel_zClearAll {this} {
-    if [$this operator] { $this zdDo delete *ALL*  } { $this zdClear }
+    if {[$this operator]} { $this zdDo delete *ALL*  } { $this zdClear }
 }
 #
 proc channel_makeZDraw {this} {
     global DIms
     set win .@zd$this
-    if [winfo exists $win] { popup $win ; return }
+    if {[winfo exists $win]} { popup $win ; return }
     set chan [$this name]
     toplevel $win -class Zircon
     wm title $win "$chan Sketch Pad"
