@@ -1,14 +1,14 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/chat.tcl,v $
-# $Date: 1997/07/18 08:01:34 $
-# $Revision: 1.18.1.4 $
+# $Date: 1998/02/10 13:27:03 $
+# $Revision: 1.18.1.6 $
 #
 package provide Dcc 1.18
 #
 proc closeChat {cht who conn} {
     catch {fileevent $conn readable {} ; close $conn}
     upvar #0 $conn chdata
-    if [info exists chdata] {
+    if {[info exists chdata]} {
 	$chdata(who) deref
 	unset chdata
     }
@@ -28,7 +28,7 @@ proc dccChat {mode conn} {
 		closeChat $cht $who $conn
 	    } {
 		regsub -all "\r" $buffer {} buffer
-		if [regexp "(\[^\001\]*)\001\[ \t\]*(\[^ \t\001\]+)\[ \t\]*(\[^\001\]*)\001(\[^\001\]*)" $buffer sub a op cp b] {
+		if {[regexp "(\[^\001\]*)\001\[ \t\]*(\[^ \t\001\]+)\[ \t\]*(\[^\001\]*)\001(\[^\001\]*)" $buffer sub a op cp b]} {
 		    set value [handleCTCP [$cht net] $op $cht Chat [$cht caller] {} {} $cp]
 		    switch {} $value return
 		    set buffer $a$value$b
@@ -42,11 +42,10 @@ proc dccChat {mode conn} {
 #
 proc user_unChServ {this} {
     upvar #0 AChat[$this net] AChat
-    if [info exist AChat($this)] {
+    if {[info exist AChat($this)]} {
 	catch {uplevel #0 unset $AChat($this)}
 	catch {close $AChat($this)}
 	unset AChat($this)
-	$this deref
     }
 }
 #
