@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1997/07/18 08:01:36 $
-# $Revision: 1.18.1.34 $
+# $Date: 1998/02/10 13:27:05 $
+# $Revision: 1.18.1.46 $
 #
 package provide Dcc 1.18
 #
@@ -19,9 +19,9 @@ proc dodRename {net file new} {
 #
 proc doGetDCC {net wh usr addr port leng posn args} {
     switch -- $args {} return
-    if [catch {set host [dectonet $addr]}] return
+    if {[catch {set host [dectonet $addr]}]} return
     switch $wh Chat {
-	if [catch {connect $host $port} sok] {
+	if {[catch {connect $host $port} sok]} {
 	    $net display {} "*** Cannot connect to host $host ($sok)"
 	    return 0
 	}
@@ -35,8 +35,8 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	$this configure -sock $sok
 	fileevent $sok readable "dccChat r $sok"
     } default {
-	if [file exists [set file [lindex $args 0]]] {
-	    if ![file writable $file] {
+	if {[file exists [set file [lindex $args 0]]]} {
+	    if {![file writable $file]} {
 		tellError {} {File error} "Cannot write file $file."
 		return 0
 	    }
@@ -49,9 +49,9 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	    1 {
 		    $net CTCP DCC [$usr name] "RESUME [file tail $file] $port $posn"
 		    global Resume
+		    if {![info exists Resume($usr)]} {$usr ref}
 		    lappend Resume($usr) \
 		      [list $file $addr $port $leng $posn]
-		    $usr ref
 		    return 0
 		}
 	    2 {
@@ -76,7 +76,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 		      [list ok "dodRename $net [list $file]"] [list cancel {}]]
 		    set v $DCCR($net,$file);
 		    unset DCCR($net,$file)
-		    if !$v {return 0}
+		    if {!$v} {return 0}
 		}
 	    4 {return 0}
 	    }
@@ -90,60 +90,65 @@ proc doGetDCC {net wh usr addr port leng posn args} {
     return 1
 }
 #
-proc dccPick {net win y} {
+proc dccPick {net win id} {
     global DCCList
-    notIdle {}
-    switch -- [set t [$win curselection]] {} {set t [$win nearest $y]}
-    set rt {}
-    foreach x $t {
-	lappend calls [lindex $DCCList($net) $x]
-	lappend rt $x
-    }
-    foreach x $rt {listdel DCCList($net) $x}
-    switch {} $DCCList($net) {destroy .@drq$net} default {
-	$win delete [lindex $t 0] [lindex $t end]
-    }
-    foreach l $calls {
-	foreach {op usr addr port fln leng posn} $l break
-	switch $op {
-	Send {handleSend $net $fln $usr $addr $port $leng $posn 0}
-	default { doGetDCC $net $op $usr $addr $port $leng $posn $fln }
-	}
-	$usr deref
+    set ix [lsearch $DCCList($net) "$id *"]
+    foreach {dm op usr addr port fln leng posn} [lindex $DCCList($net) $ix] break
+    switch $op {
+    Send {handleSend $net $fln $usr $addr $port $leng $posn 0}
+    default { doGetDCC $net $op $usr $addr $port $leng $posn $fln }
     }
+    dccDel $net $win $id $usr
 }
 #
-proc dccDel {net win} {
-    notIdle {}
-    switch {} [set t [$win curselection]] return
+proc dccDel {net w id usr} {
     global DCCList
-    $win delete [lindex $t 0] [lindex $t end]
-    foreach x $t {
-	catch {[lindex [lindex $DCCList($net) $t] 1] deref}
-	listdel DCCList($net) $t
+    notIdle {}
+    listdel DCCList($net) [lsearch $DCCList($net) "$id *"]
+    $usr deref
+    if {[winfo exists $w]} {
+	destroy $w.t$id $w.u$id $w.f$id $w.a$id $w.c$id
+	if {[llength [winfo children $w]] <= 1} {
+	    set z [winfo parent $w]
+	    closeFrame [winfo parent $z] [winfo name $z]
+	}
+	switch {} $DCCList($net) {destroy [winfo toplevel $w]}
     }
-    switch {} $DCCList($net) {destroy .@drq$net}
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
 #
 proc addDCCRequest {net op usr fln addr port leng} {
-     global DCCList
-     if ![winfo exists [set w .@drq$net]] {
+    global DCCList
+    if {![winfo exists [set w .@drq$net]]} {
 	set DCCList($net) {}
 	toplevel $w -class Zircon
-	wm title $w {Incoming DCC Requests}
-	wm protocol $w WM_DELETE_WINDOW { }
-	makeLB $w.lb -setgrid 1 -width 40 -height 8 
-	grid $w.lb
-	bind $w.lb.l <Double-Button-1> "dccPick $net %W %y ; break"
-	bind $w.lb.l <Delete> "dccDel  $net %W ; break"
-	bind $w.lb.l <BackSpace> [bind %W <Delete>]
-	bind $w.lb.l <Control-h> [bind %W <Delete>]
-	bind $w.lb <Any-Enter> {focus %W.l ; notIdle {} ; break}
-     }
-     $w.lb.l insert end "[$usr name] : $op $fln"
-     popup $w
-     lappend DCCList($net) [list $op $usr $addr $port $fln $leng 0 0]
-     $usr ref
+	wm title $w "[$net name] - Incoming DCC Offers"
+	addSeparator [switchFrame $w sChat {Chat Offers}] \
+	  -columnspan 5
+	addSeparator [switchFrame $w sSend {File Send Offers}] \
+	  -columnspan 5
+	grid columnconfigure $w.sChat.bdy 1 -weight 1
+	grid columnconfigure $w.sChat.bdy 2 -weight 1
+	grid columnconfigure $w.sSend.bdy 1 -weight 1
+	grid columnconfigure $w.sSend.bdy 2 -weight 1
+    } {
+	if {[set dl [$net dcclimit]] && [llength $DCCList($net)] > $dl} return
+    }
+    set win $w.s$op.bdy
+    set rw [lindex [grid size $win] 1]
+    set ix [newName dcc]
+    grid [label $win.t$ix -text [getDate]] -row $rw -column 0 -sticky w
+    grid [label $win.u$ix -text [$usr name]] -row $rw -column 1 -sticky w -padx 5
+    grid [label $win.f$ix -text $fln] -row $rw -column 2 -sticky w -padx 5
+    grid [button $win.a$ix -text [trans accept] -command "dccPick $net $win $ix"]\
+      -sticky ew -row $rw -column 3
+    grid [button $win.c$ix -text [trans cancel] -command "dccDel $net $win $ix $usr"]\
+      -sticky ew -row $rw -column 4
+    popup $w
+    openFrame $w s$op
+    lappend DCCList($net) [list $ix $op $usr $addr $port $fln $leng 0 0]
+    $usr ref
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
 #
 proc handleDCC {net usr param prefix} {
@@ -158,7 +163,7 @@ proc handleDCC {net usr param prefix} {
 	    switch -glob -- $fln {.*} {set fln _[string range $fln 1 end]}
 	    set leng [lindex $pars 4]
 	    foreach x [$net autoget] {
-		if [regexp $x $prefix] {
+		if {[regexp $x $prefix]} {
 		    handleSend $net $fln $usr $addr $port $leng 0 1
 		    return
 		}
@@ -166,8 +171,12 @@ proc handleDCC {net usr param prefix} {
 	    addDCCRequest $net Send $usr $fln $addr $port $leng
 	}  
     CHAT {
+	    switch WBOARD [string toupper $fln] {
+		$net inform "Zircon does not implement DCC WBOARD"
+		return
+	    }
 	    foreach x [$net autochat] {
-		if [regexp $x [string range $prefix 1 end]] {
+		if {[regexp $x [string range $prefix 1 end]]} {
 		    doGetDCC $net Chat $usr $addr $port {} 0 {}
 		    return
 		}
@@ -177,12 +186,6 @@ proc handleDCC {net usr param prefix} {
     }
 }
 #
-proc ipPack {ip} {
-    set val 0
-    foreach x [split $ip "."] {	set val [expr {($val << 8) + $x}] }
-    return [format %u $val]
-}
-#
 proc dectonet {dec} {
     if {[string length $dec] == 10 && [set first [string index $dec 0]] > 1} {
 	switch -- $first {
@@ -209,12 +212,12 @@ proc dectonet {dec} {
 proc killDel {arr usr file} {
     upvar #0 $arr gs
     set i 0
-    if ![info exists gs($usr)] return
+    if {![info exists gs($usr)]} return
     foreach p $gs($usr) {
 	switch -- [lindex $p 1] $file {
 	    catch {exec kill -9 [pid [lindex $p 0]]} msg
 	    listdel gs($usr) $i
-	    switch -- $gs($usr) {} {unset gs($usr) ; $usr deref}
+	    switch {} $gs($usr) {unset gs($usr)}
 	    set conn [lindex $p 2]
 	    catch {fileevent $conn readable {}}
 	    catch {close $conn}
@@ -224,74 +227,106 @@ proc killDel {arr usr file} {
     }
 }
 #
-proc dccClose {net win} {
-    foreach t [$win curselection] {
-	set x [split [$win get $t]]
-	set usr [User :: find [set who [lindex $x 2]] $net]
-	set file [lindex $x 4]
-	switch -glob -- $x {
-	{Call -*} {$usr unChat }
-	{Call from*} { }
-	Chat* {catch {[Chat :: find $who $net] leave}}
-	Get* -
-	Send* -
-	Offer* {
-		set arr [lindex $x 0]
-		upvar #0 $arr$net av
-		foreach f $av($usr) {
-		    switch -- $file [lindex $f 1] {
-			killDel $arr$net $usr $file
-			break
-		    }
+proc dccClose {net op usr file ix w} {
+    set who [$usr name]
+    switch -glob -- $op {
+    Call {$usr unChat }
+    Chat {catch {[Chat :: find $who $net] leave}}
+    Get -
+    Send -
+    Offer {
+	    upvar #0 $op$net av
+	    foreach f $av($usr) {
+		switch -- $file [lindex $f 1] {
+		    killDel $op$net $usr $file
+		    break
 		}
 	    }
-	Request* { }
+	    destroy $w.f$ix
 	}
     }
-    foreach t [$win curselection] { $win delete $t }
+    destroy $w.l$ix $w.b$ix
+    buildDCCList $net
+}
+#
+proc doTitle {grd w sub ttl} {
+    if {$grd > 1} { openFrame $w $sub } { closeFrame $w $sub }
 }
 #
 proc buildDCCList {net args} {
+    global zircon
     set w .@dls$net
-    if [winfo exists $w] {
+    array set tls {
+	coff	{Chat Offers}
+	achat	{Active Chats}
+	fOffer	{File Offers}
+	fSend	{Active File Sends}
+	fGet	{Active File Gets}
+    }
+    if {[winfo exists $w]} {
 	popup $w
-	switch -- $args {} {$w.dcc.l delete 0 end}
+	switch -- $args {} {
+	    foreach x [winfo children $w] {
+		catch {eval destroy [winfo children $x.bdy]}
+		addSeparator $x.bdy -columnspan 3 -row 0
+	    }
+	}
     } {
 	toplevel $w -class Zircon -relief raised -borderwidth 2
 	wm title $w "[$net name] - DCC Connections"
-	wm protocol $w WM_DELETE_WINDOW "destroy $w"
-	grid columnconfigure $w 0 -weight 1
-	grid rowconfigure $w 0 -weight 1
-	makeLB $w.dcc -setgrid 1
-	frame $w.btn
-	grid columnconfigure $w.btn 0 -weight 1
-	grid columnconfigure $w.btn 1 -weight 1
-	button $w.btn.ok -text [trans dismiss] -command "destroy $w" -relief raised
-	button $w.btn.close -text [trans close] -relief raised \
-	  -command "dccClose $net $w.dcc.l"
-	grid $w.btn.ok $w.btn.close -sticky ew
-	grid $w.dcc -sticky nsew
-	grid $w.btn -sticky ew
+	wm resizable $w 0 0
+	foreach x {coff achat fOffer fSend fGet} {
+	    set w1 [switchFrame $w $x $tls($x)]
+	    addSeparator $w1 -columnspan 3
+	    grid columnconfigure $w1 1 -weight 1
+	}
     }
-    set cnt 0
     upvar #0 Offer$net Offer Send$net Send Get$net Get AChat$net AChat
+    set w1 $w.coff.bdy
+    set grd 1
+    grid columnconfigure $w1 0 -weight 1
     foreach nn [array names AChat] {
-	$w.dcc.l insert end "[trans call] - [$nn name]"
-	incr cnt
+	set ix [newName dcc]
+	grid [label $w1.l$ix -text [$nn name]] -row $grd -column 0\
+	  -sticky w -padx 5 -columnspan 2
+	grid [button $w1.b$ix -text [trans cancel] \
+	  -command "dccClose $net Call $nn {} $ix $w1"] -row $grd \
+	  -column 2 -sticky ew
+	incr grd
     }
+    doTitle $grd $w coff $tls(coff)
+    set w1 $w.achat.bdy
+    set grd 1
     foreach nn [$net chats] {
 	switch -- [set nm [$nn name]] *default* {} default {
-	    $w.dcc.l insert end "[trans chat] - $nm"
-	    incr cnt
+	    set ix [newName dcc]
+	    grid [label $w1.l$ix -text $nm] -row $grd \
+	      -column 0 -sticky w -padx 5 -columnspan 2
+	    grid [button $w1.b$ix -text [trans cancel] \
+	      -command "dccClose $net Chat $nn {} $ix $w1"] \
+	      -sticky ew -row $grd -column 2
+	    incr grd
 	}
     }
+    doTitle $grd $w achat $tls(achat)
     foreach arr {Offer Send Get} {
+	set w1 $w.f$arr.bdy
+	grid columnconfigure $w1 1 -weight 1
+	set grd 1
 	foreach nn [array names $arr] {
 	   foreach fl [set ${arr}($nn)] {
-		$w.dcc.l insert end "[trans $arr] - [$nn name] : [lindex $fl 1]"
-		incr cnt
-	   }
+		set ix [newName dcc]
+		grid [label $w1.l$ix -text [$nn name]] \
+		  -row $grd -column 0 -sticky w -padx 5
+		grid [label $w1.f$ix -text [lindex $fl 1]] \
+		  -row $grd -column 1 -sticky w -padx 5
+		grid [button $w1.b$ix -text [trans cancel] \
+		  -command "dccClose $net $arr $nn [lindex $fl 1] $ix $w1"]\
+		  -sticky ew -row $grd -column 2
+		incr grd
+	    }
 	}
+	doTitle $grd $w f$arr $tls(f$arr)
     }
 }
 #
@@ -319,6 +354,7 @@ proc dccCheck {net interval} {
 		lappend dy [lreplace $off 5 5 $time]
 	    } {
 		set chng 1
+		catch {close [lindex $off 2]}
 	    }
 	}
 	switch {} [set Offer($x) $dy] {unset Offer($x)}
@@ -327,32 +363,30 @@ proc dccCheck {net interval} {
     set dy {}
     set del {}
     set indx 0
-    if [info exists DCCList($net)] {
+    if {[info exists DCCList($net)]} {
 	foreach x $DCCList($net) {
-	    switch [lindex $x 0] {
+	    switch [lindex $x 1] {
 	    Chat -
 	    Send {
-		set time [lindex $x 7]
+		set time [lindex $x 8]
 		if {[incr time $interval] < 600000} {	    
-		    lappend dy [lreplace $x 7 7 $time]
+		    lappend dy [lreplace $x 8 8 $time]
 		} {
 		    set chng 1
-		    set del [linsert $del 0 $indx]
+		    lappend del [list [lindex $x 0] [lindex $x 2]]
 		}
 		continue
 	    }
 	    default { lappend dy $x }
 	    }
 	    incr indx
-        }
-        switch {} [set DCCList($net) $dy] {catch {destroy .@drq$net}}
+	}
+	switch {} [set DCCList($net) $dy] {catch {destroy .@drq$net}}
     }
-    if $chng {
-	if [winfo exists .@dls$net] {buildDCCList $net}
-	if [winfo exists .@drq$net] {
-	    foreach x $del {
-		.@drq$net.lb.l delete $x
-	    }
+    if {$chng} {
+	if {[winfo exists .@dls$net]} {buildDCCList $net}
+	if {[winfo exists .@drq$net]} {
+	    foreach x $del {dccDel $net .@drq$net [lindex $x 0] [lindex $x 1]}
 	}
     }
 }
@@ -382,26 +416,29 @@ proc user_dcc {this cmd} {
 		  [list send "DCCSend $this"] [list cancel {}]
 	    } default {
 		global SendDir zFileTypes
-		if [catch {set dir $SendDir($net)}] {
+		if {[catch {set dir $SendDir($net)}]} {
 		    set SendDir($net) [set dir [pwd]]
 		}
-		set fl [tk_getOpenFile -initialdir $dir \
-		  -title "DCC send file to $nk" -filetypes $zFileTypes]
-		set SendDir($net) [file dirname $fl]
-		DCCSend $this $fl
+		switch {} [set fl [tk_getOpenFile -initialdir $dir \
+		  -title "DCC send file to $nk" -filetypes $zFileTypes]] {
+# user hit cancel
+		} default {
+		    set SendDir($net) [file dirname $fl]
+		    DCCSend $this $fl
+		}
 	    }
 	}
     CHAT {
 	    upvar #0 AChat$net AChat
-	    if [info exist AChat($this)] {
-		if [askUser {} Chat  \
-		  "You already have a chat request pending for $nk. Close it?"] {
+	    if {[info exist AChat($this)]} {
+		if {[askUser {} Chat  \
+		  "You already have a chat request pending for $nk. Close it?"]} {
 		    $this unChat
 		}
 	    } \
 	    elseif {[string compare nil [Chat :: find $nk [$this net]]]} {
-		if [askUser {} Chat  \
-		  "You already have a chat request pending for $nk. Close it?"] {
+		if {[askUser {} Chat  \
+		  "You already have a chat request pending for $nk. Close it?"]} {
 		    $this unChat
 		}
 	    } \
@@ -413,3 +450,6 @@ proc user_dcc {this cmd} {
 	}
     }
 }
+#
+proc unsetSGO {arr elem op} { $elem deref }
+#
